function [nedits nbreaks nedit_code nbreak_code] = EqEdit(edits, edit_code, breaks, break_code, name, Stot, eqeq, eqrn, times,symnum,sym)
% Function to update the edits and breaks informations based on earthquake
% and rename data

% See if any earthquakes
nedits = edits; nbreaks = breaks;
nedit_code = edit_code; nbreak_code = break_code;
if ~isempty(eqeq)
    eq_code = eqeq.EQ_CODE;
    neq = size(eq_code,1);
else
    neq = 0;
end
if  neq > 0
    % Then we have earthquakes; loop over earthquakes and see if this site
    % is effected
    XYZ_site = GEOD_to_XYZ([90-Stot(1) Stot(2) Stot(3)]);
    eq_par = eqeq.EQ_PAR;
    eq_log = eqeq.EQ_LOG; eq_exp = eqeq.EQ_EXP; % eq_cos = eqeq.EQ_COS; 
    % Loop over Eq's to see if affected
    for k = 1:neq
        geodeq = [90-eq_par(1,k) eq_par(2,k) -eq_par(4,k)*1000];
        XYZ_eq = GEOD_to_XYZ(geodeq);
        dist = sqrt((XYZ_site-XYZ_eq)*(XYZ_site-XYZ_eq)');
        if dist < eq_par(3,k)*1000 
            % This earhquake effects the site; Check type of break to add
            teq = eq_par(5,k);
            maglog = sqrt(eq_log(2:7,k)'*eq_log(2:7,k));
            magexp = sqrt(eq_exp(2:7,k)'*eq_exp(2:7,k));
            if maglog == 0 && magexp == 0 
                nbreaks = [breaks ; teq 0 0 0 0 3 ];
            elseif maglog > 0
                nbreaks = [breaks ; teq eq_log(1,k)/365  0 0 0 3];
            else
                nbreaks = [breaks ; teq teq+eq_exp(1,k)/365 0 0 0 2];
            end
            nbreak_code = [break_code; 3];
        end
        breaks = nbreaks;
        break_code = nbreak_code;
    end
end


% See if we should report edits
hr = findobj(gcf,'Tag','ReportEdits'); ReportEdits = get(hr,'Value');

% See if renames affect the site
if ~isempty(eqrn)
    rn_n1 = eqrn.RN_N1;
    nrn = size(rn_n1,1);
else
    nrn = 0;
end
if nrn > 0
    % See if we can match the name
    rn_n2 = eqrn.RN_N2; rn_yr = eqrn.RN_YR; rn_cen = {eqrn.RN_CN}; brk_cod = eqrn.RN_CD;
    sname = name(1:4);
    for k = 1:nrn
        cen = rn_cen{k};
        OK = 1; 
        if ~strcmp(cen,'@')   % If the cen have been given (not default @)
            match = strfind(name,cen);
            if isempty(match)
                OK = 0;    % cen string was given and does not match the 
                           % name here so do not allow the edit.
            else
                OK = 1;
            end
        end
        if  strcmpi(sname,rn_n1(k,1:4)) && OK == 1
            % Names match, now see if this is edit or a break.  Edits will
            % have rename name with _X in it; 
            if strcmp(rn_n2(k,5:6),'_X')
                tedits = find(times > rn_yr(k,1) & times < rn_yr(k,2) & symnum == sym);
                if ~isempty(tedits) 
                  nedits = [edits tedits];
                  nedit_code = [edit_code; tedits brk_cod(k)];
                end
            else
                nbreaks = [breaks ; rn_yr(k,1) 0  0 0 0 0];
                nbreak_code = [break_code; brk_cod(k)];
            end
        end
        breaks = nbreaks;
        edits = nedits;
        break_code = nbreak_code;
        edit_code = nedit_code;
    end
end
%
% If we are reporting Output now
if ReportEdits
    if ~isempty(nedits) 
        fprintf('Edits applied to time series from EQ file\n')
    end
    for k = 1:length(nedits)
        fprintf(1,'Edit %6d Date %4d %2d %2d %2d %2d \n',  k,YrToDate(times(nedits(k)),5));
    end
end
                     
% Check for duplicates
[nbreaks nbreak_code] = checkbr(breaks,break_code);


        
    
                
            
        
        

    
