function fig = tsview(insite,udir)
% This is the machine-generated representation of a Handle Graphics object
% and its children.  Note that handle values may change when these objects
% are re-created. This may cause problems with any callbacks written to
% depend on the value of the handle at the time the object was saved.
%
% To reopen this object, just type the name of the M-file at the MATLAB
% prompt. The M-file and its associated MAT-file must be on your path.
tsver = 2.04;
if nargin == 0
    udir = '';insite='';

%   Print a small help description
    fprintf('++++++++++++++++++++++++++\n');
    fprintf('+ TSVIEW    Version %4.2f +\n',tsver);
    fprintf('++++++++++++++++++++++++++\n\n');
    fprintf('Time series analysis using either mb_  files generated by GAMIT program multibase or\n');
    fprintf('*frame.pos files distrubuted by PBO.  Only one type of file may in the directory.\n');
    fprintf('Results can be saved in the files listed in the lower left cornor of GUI. \n');
    fprintf('Directory can be changed using box at the top of the screen\n\n');
    fprintf('Version 1.03: Compatable with Matlab Ver 7\n');
    fprintf('Version 2.00: PBO *frame.pos files incorporated\n');
    fprintf('Version 2.01: Added reading Globk earthquake file\n');
    fprintf('Version 2.02: Allowed names with different frames so search for .pos file\n');
    fprintf('              PBO name form is: <cen>.<type>_<frame>.pos with 3-char cen, 5-char type (e.g., final) and\n');
    fprintf('              5-char frame (e.g., igs05, snf10, frame)\n')
    fprintf('Version 2.03: Added Spectral Analysis using fastlomb algorithm\n');
    fprintf('Version 2.04: Allow multiple earthquake files to be read (C button to clear)\n');
    fprintf('              Support for new .pos headers, changed Zoom\n\n');

elseif nargin == 1, udir = '';
end
if ~isempty(insite) 
    fprintf('Running with Site %s Directory %s\n',insite,udir);
end
% Get the version of Matlab.  This will effect how certain commands are used
%aver = ver('MATLAB') ; mver = str2num(aver.Version(1:3));
%mver = 6.1;  % Not need with bug fix to 7.0

% Reset the default line width in user has overwritten

set(0,'DefaultLineLineWidth',0.5);
set(0,'DefaultAxesBox','on');
set(0,'DefaultAxesTickDir','in');
set(0,'DefaultUicontrolFontSize',9)
set(0,'DefaultAxesFontSize',9)

% Build some structures that we will need 
breaks = []; edits=[]; Strend=[];Stot=[]; outall_save=[]; symnum=[];
% MOD TAH 070814: Added structures for Earthquake file and pname for plot
% name (includes appended and differenced sites)
pname = []; break_code=[]; edit_code=[]; eqfile = [];
savecom = struct('Udir',udir,'Breaks',breaks,'Edits',edits, ...
    'Strend',Strend,'Stot',Stot,'Outall_save',outall_save, ...
    'Symnum',symnum,'PName',pname, ...
    'Break_code',break_code,'Edit_code',edit_code,'EqFile',eqfile);

eqrn = []; eqeq = [];
saveeq = struct('EqRn',eqrn,'EqEq',eqeq);

% Generate the list of sites that are needed.
sites = GetSites(udir); 

% See if an argument has been passed
selsite = 0;
if nargin >= 1 
    % Name of site has been passed so pass this to GUI
    ls = length(insite);
    for i = 1:length(sites)
       if strcmp(sites(i,1:ls),insite(1:ls))  && selsite == 0 
           selsite = i; 
       end
    end
    % If we did not find the site, see if the first 4 characters can be
    % matched
    if selsite == 0 
        fprintf(1,'Selected site %s not found initially, getting close name\n',insite);
        for i = 1:length(sites)
            if sites(i,1:4) == insite(1:4) && selsite == 0 , selsite = i ; end
        end
        if selsite ~= 0
            fprintf(1,'Match found to %s\n',sites(selsite,:));
        else
            fprintf(1,'No 4-character matach found\n');
        end
    end
    fprintf(1,'Site number %d selected\n',selsite);
end

% Set root units to pixels and get screen size
set(0,'Units','pixels') ;
scnsize = get(0,'ScreenSize');

% Set an effective Max screen Size
if scnsize(3) > 1280 , scnsize(3) = 1280; end
if scnsize(4) >  960 , scnsize(4) =  960; end
 
% Compute the Figure size we want
figsize = [(scnsize(3)-scnsize(1))*0.93 (scnsize(4)-scnsize(2))*0.85];

% Set the border widths of the figure shell
bdwidth = figsize(2)*0.02;
%topbdwidth = figsize(2)*0.05;
% Set the size of the axis and the space in brtween
axisspace = figsize(2)*0.05;
axiswt = figsize(1)*0.68;
axisht = figsize(2)*0.25;

% Compute and set the position and size of the figure shell 
pos = [4*bdwidth, 4*bdwidth, figsize(1) figsize(2) ];
h0 = figure('Units','pixels', ...
	'ResizeFcn','GPSResize;', 'Color',[0.8 0.8 0.8], ...
	'Position',pos, 'ToolBar','figure', 'MenuBar','figure',...
	'Tag','Fig1');

% Save the "to be" presistent variables in the figure header
set(h0,'UserData',savecom);
set(h0,'UserData',savecom);

% Compute and set the position and size axis 1 (N component) 
pos = [bdwidth + figsize(1)*0.28,... 
       bdwidth + axisspace*3 + (axisht)*2,...
       axiswt, axisht];
axes('Parent',h0, ...
	'Units','pixels', ...
	'CameraUpVector',[0 1 0], ...
	'Color',[1 1 1],  ...
	'Position',pos, ...
	'Tag','Axis1', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
% Compute and set the position and size axis 2 (E component) 
pos = [bdwidth + figsize(1)*0.28,... 
       bdwidth + axisspace*2  + axisht,...
       axiswt, axisht];
axes('Parent',h0, ...
	'Units','pixels', ...
	'CameraUpVector',[0 1 0], ...
	'Color',[1 1 1], ...
	'Position',pos, ...
	'Tag','Axis2', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
% Compute and set the position and size axis 3 (U component) 
pos = [bdwidth + figsize(1)*0.28,... 
       bdwidth + axisspace,...
       axiswt, axisht];
axes('Parent',h0, ...
	'Units','pixels', ...
	'CameraUpVector',[0 1 0], ...
	'Color',[1 1 1], ...
	'Position',pos, ...
	'Tag','Axis3', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);

% Put a Directory box at the top of the screen
pos = [ bdwidth*2, figsize(2)-2*bdwidth, 80 bdwidth*1.5];
lab = sprintf('V %4.2f: Dir',tsver);
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Position',pos, ...
	'String',lab, ...
	'Style','pushbutton', ...
    'Callback','gpsgui(''Dir'')',... 
    'TooltipString','Click to load names from directory',...
	'Tag','DirLabel');

pos = [ bdwidth*2+80, figsize(2)-2*bdwidth, figsize(1)*0.2 bdwidth*1.5];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Position',pos, ...
	'String',udir, ...
	'Style','edit', 'HorizontalAlignment','left', ...
    'Callback','gpsgui(''Dir'')',... 
    'TooltipString','Type the name of a directory constaining mb_XXXX or .pos files here',...
	'Tag','DirName');


% Compute and set the position and size of the site list box 
pos = [bdwidth*2,... 
       axisht*1.35,...
       figsize(1)*0.1, figsize(2)-axisht*1.35-2*bdwidth];
hs = uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'BackgroundColor',[1 1 1], ...
	'Position',pos, ...
	'String',sites, ...
	'Style','listbox', ...
	'Tag','ListboxSites', ...
	'Value',1, ...
	'UserData',sites) ;

% If the site has been passed save its value in the uicontrol
if selsite ~= 0 , set(hs,'Value',selsite); end

lbtop = axisht + figsize(2)-axisht-2*bdwidth;
lbbot = axisht*1.35;

% Compute and set the position and size of the gui buttons
buttony = figsize(2)*0.041;
buttonx = figsize(1)*0.09;
buttonxpos = pos(1) + pos(3) + bdwidth;
buttonypos = lbtop - buttony; 
%buttonspace = figsize(2)*0.004;
% Use some short names
byp = buttonypos;
bys = figsize(2)/39; byh = bys*0.95;

% Load button
pos = [buttonxpos, byp, buttonx, byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Callback','gpsgui(''Load'')', ...
	'Position',pos, ...
    'Value',1, ...
	'String','Load', ...
	'Tag','Pushbutton1', ...
	'TooltipString','Load Selected Data');

% Append button
pos = [buttonxpos, byp - bys, buttonx, byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Callback','gpsgui(''Append'')', ...
	'Position',pos, ...
	'String','Append', ...
	'Tag','Pushbutton2', ...
	'TooltipString','Append data to current');
% Offset on Append button
pos = [buttonxpos+buttonx+1, byp - bys, 25, 15];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Position',pos, ...
    'Style','checkbox', ...
    'FontSize',12, ...
	'Tag','OffApp', ...
	'TooltipString','Check to allow offsets at overlapping times on append');

% MOD TAH 060125: Add a difference button
pos = [buttonxpos, byp-2*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Callback','gpsgui(''Difference'')', ...
	'Position',pos, ...
	'String','Difference', ...
	'Tag','Difference', ...
	'TooltipString','Difference from current data');

  
% Detrend button
byp = byp - bys;
pos = [buttonxpos, byp-2*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Position',pos, ...
	'Callback','gpsgui(''Detrend'')', ...
	'String','Detrend', ...
	'Tag','Pushbutton3', ...
	'TooltipString','Detrend time series based on parameters selected');

% Edit Button
pos = [buttonxpos, byp-3*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Callback','gpsgui(''Edit'')', ...
	'Position',pos, 'FontSize',9,...
	'String','Edit', ...
	'Tag','Pushbutton4', ...
	'TooltipString','Edit data, Right mouse button allows repeated selection');

% Block Edit button
pos = [buttonxpos, byp-4*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Callback','gpsgui(''BlockEdit'')', ...
	'Position',pos, 'FontSize',9,...
	'String','Block Edit', ...
	'Tag','Pushbutton6', ...
	'TooltipString','Select region to edit');
      
% Break button
pos = [buttonxpos, byp-5*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Callback','gpsgui(''Break'')', ...
	'Position',pos, 'FontSize',9,...
	'String','Break', ...
	'Tag','Pushbutton5',...
	'TooltipString','Insert breaks data, Right mouse button allows repeated selection');

% Exponent decay button
pos = [buttonxpos, byp-6*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Callback','gpsgui(''Exponent'')', ...
	'Position',pos, 'FontSize',9,...
	'String','Exponent', ...
	'Tag','ExponentButton',...
	'TooltipString','Click and drag to select start and end of exponent interval');

% Logarithmic button
pos = [buttonxpos, byp-7*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Callback','gpsgui(''Log'')', ...
	'Position',pos,'FontSize',9, ...
	'String','Log', ...
	'Tag','LogButton',...
	'TooltipString','Click and drag back to start of log function');

% Edit Break buttons
pos = [buttonxpos, byp-8*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Callback','gpsgui(''EditBreak'')', ...
	'Position',pos, 'FontSize',9,...
	'String','Edit Breaks', ...
	'Tag','EditBreak',...
	'TooltipString','Click to edit breaks tables');

% Zoom button
pos = [buttonxpos, byp-9*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Callback','gpsgui(''Zoom'')', ...
	'Position',pos, ...
	'String','Zoom', ...
	'Tag','ZoomButton', ...
	'TooltipString','Select region to zoom; all axes zoom'); 

% Span button
pos = [buttonxpos, byp-10*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Callback','gpsgui(''Span'')', ...
	'Position',pos, ...
	'String','Span', ...
	'Tag','Pushbutton7', ...
	'TooltipString','Select region to span'); 

% Save button
pos = [buttonxpos, byp-11*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Callback','gpsgui(''Save'')', ...
	'Position',pos, ...
	'String','Save', ...
	'Tag','Pushbutton8', ...
	'TooltipString','Save edit and break information to a file'); 

% Maximum size of outliers button
pos = [buttonxpos, byp-12.4*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Position',pos, ...
	'String','Outliers (n-sigma)', ...
    'FontSize',9, ...
	'Style','text', ...
	'Tag','Text1');
% Button selector.  
% Mod Ver 1.03: Need to add buttons in uipanel in Matalb 7.0
% Bug is fixed so no longer needed
%if mver < 7 
   posp = [buttonxpos, byp-13*bys, buttonx,byh];
   hlp = h0;
%else
%   pos = [0,0, 1,1];
%   hlp = uipanel('Parent',h0, 'Units','Pixels', 'Position',pos);
%   posp = [buttonxpos, byp-13*bys, buttonx,byh];
%end
uicontrol('Parent',hlp, ...
	'Units','pixels', ...
	'Position',posp, ...
	'String',['1  ';'2  ';'3  ';'4  ';'5  ';'all'], ...
	'Style','popupmenu', ...
	'Tag','Outlier', ...
	'TooltipString','Select outlier editing criteria', ...
	'Value',6); 

% Maximum sigma text box
pos = [buttonxpos, byp-14.4*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Position',pos, ...
	'String','Max Sigma (mm)', ...
    'FontSize',9, ...
	'Style','text', ...
	'Tag','Text2');
pos = [buttonxpos, byp-15*bys, buttonx,byh];
hn = uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Position',pos, ...
    'HorizontalAlignment','right', ...
	'Style','edit', ...
	'Tag','SigmaCut', ...
	'TooltipString','Enter sigma editing criteria');
set(hn,'String',sprintf('%6.1f',1000.0));
   
% Retain breaks button 
pos = [buttonxpos, byp-16*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Position',pos, ...
	'String','Keep Breaks', ...
    'FontSize',9, ...
	'Style','checkbox', ...
	'Tag','RetainBreaks', ...
    'TooltipString','Check to retain breaks on Load');

% Add break on append
pos = [buttonxpos, byp-17*bys, buttonx,byh];
% Set the default to be on for the break on append button
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Position',pos, ...
	'String','Brk on Appnd', ...
    'Value',1, ...
    'FontSize',9, ...
    'Style','checkbox', ...
	'Tag','AppendBreaks', ...
    'TooltipString','Check to automatically add break on append');

% Report Edits to MATLAB Main window
pos = [buttonxpos, byp-18*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Units','pixels', ...
	'Position',pos, ...
	'String','Report Edits', ...
    'FontSize',9, ...
    'Style','checkbox', ...
	'Tag','ReportEdits', ...
    'TooltipString','Check to report edited values to Matlab Command Window');

% Boxes to edit the breaks
pos = [buttonxpos, byp-19.4*bys, buttonx,byh];
uicontrol('Parent',h0, ...
	'Position',pos, ...
	'String','Delete Breaks', ...
    'FontSize',9, ...
	'Style','text', ...
	'Tag','BreakList');

% Button selector
% No longer needed
%if mver < 7 
   hlp = h0;
   posp = [buttonxpos, byp-20*bys, buttonx,byh];
%else
%   pos = [0,0, 1,1];
%   hlp = uipanel('Parent',h0, 'Units','pixels', 'Position',pos,...
%                 'Tag','DBreaks');
%   posp = [ 0, 0, buttonx,byh] ;
%end
uicontrol('Parent',hlp, ...
	'Units','pixels', ...
	'Position',posp, ...
    'Callback','gpsgui(''DeleteBreak'')', ...
	'String','None', ...
    'FontSize',9, ...
	'Style','popupmenu', ...
	'Tag','DeleteBreak', ...
	'TooltipString','Select Break to be removed', ...
	'Value',1); 

% Parameter estimate and model buttons
pos = [buttonxpos, byp-21.2*bys, buttonx,byh*0.75];
uicontrol('Parent',h0, ...
	'Position',pos, ...
	'String','Parameter Set', ...
    'FontSize',9, ...
	'Style','text', ...
	'Tag','ParamSet');
% Currently three buttons that work down from here
% MOD : Rescaled panel to add two new options
byppn = byp-22*bys; byhp = byh*0.9; 

uicontrol('Parent',h0, ...
	'Position',[buttonxpos, byppn, buttonx,byhp], ...
	'String','Linear Only Res', ...
    'FontSize',9, ...
    'Style','checkbox', ...
	'Tag','LORes', ...
    'TooltipString','Only remove breaks and linear terms in display');

uicontrol('Parent',h0, ...
	'Position',[buttonxpos, byppn-1*bys*0.7, buttonx,byhp], ...
	'String','No EQ Offset', ...
    'FontSize',9, ...
    'Style','checkbox', ...
	'Tag','NoEQOff', ...
    'TooltipString','Check not remove earthquake offsets in Linear only residuals');

uicontrol('Parent',h0, ...
	'Position',[buttonxpos, byppn-2*bys*0.7, buttonx,byhp], ...
	'String','+Annual', ...
    'FontSize',9, ...
    'Style','checkbox', ...
	'Tag','Annual', ...
    'TooltipString','Estimate Annual Signal');
uicontrol('Parent',h0, ...
	'Position',[buttonxpos, byppn-3*bys*0.7, buttonx,byhp], ...
	'String','+Semiannual', ...
    'FontSize',9, ...
    'Style','checkbox', ...
	'Tag','Semiannual', ...
    'TooltipString','Estimate Annual and semiannual Signal');
uicontrol('Parent',h0, ...
	'Position',[buttonxpos, byppn-4*bys*0.7, buttonx,byhp], ...
	'String','Exp Rates', ...
    'FontSize',9, ...
    'Style','checkbox', ...
	'Tag','ExpRates', ...
    'TooltipString','Check to have different rates before and after exponentials');
uicontrol('Parent',h0, ...
	'Position',[buttonxpos, byppn-5*bys*0.7, buttonx,byhp], ...
	'String','RealSigma', ...
    'FontSize',9, ...
    'Style','checkbox', ...
	'Tag','RealSigma', ...
    'TooltipString','Check to have sigmas reflect realistic uncertainities');
uicontrol('Parent',h0, ...
	'Position',[buttonxpos, byppn-6*bys*0.7, buttonx,byhp], ...
	'String','DisplayFit', ...
    'FontSize',9, ...
    'Style','checkbox', ...
	'Tag','DisplayFit', ...
    'TooltipString','Check to display chi^2 as function of averaging interval');
uicontrol('Parent',h0, ...
	'Position',[buttonxpos, byppn-7*bys*0.7, buttonx,byhp], ...
	'String','PostEQ Timeseries', ...
    'FontSize',9, ...
    'Style','checkbox', ...
	'Tag','PVOTS', ...
    'TooltipString','Check to generates PVO files with post-earthquake time series');
%
%%% Now we get into the averaging selections.
uicontrol('Parent',h0, ...
	'Position',[buttonxpos, byp-28*bys, buttonx,byh], ...
	'String','Average', ...
    'FontSize',9, ...
	'Callback','gpsgui(''Average'')', ...
    'Style','pushbutton', ...
	'Tag','Average', ...
    'TooltipString','Average time series residuals using averaging interval below. Optional boundary date can be added');
uicontrol('Parent',h0, ...
	'Position',[buttonxpos, byp-29*bys, buttonx,byh], ...
	'String','30', ...
    'FontSize',9, ...
    'HorizontalAlignment','right', ...
    'Style','edit', ...
	'Tag','AvgLength', ...
    'TooltipString','Length of averaging interval (days)');
% Add option to hide error bars
uicontrol('Parent',h0, ...
	'Position',[buttonxpos, byp-30*bys, buttonx,byh], ...
	'Callback','gpsgui(''HideErrb'')', ...
	'FontSize',9,...
	'String','Hide Error Bars', ...
	'Tag','HideErrb',...
	'TooltipString','Click to hide the error bars on data');

% Spectral Analysis
% place holder for putting in a Lomb Periodogram MM
uicontrol('Parent',h0, ...
	'Position',[buttonxpos, byp-31*bys, buttonx,byh], ...
 	'String','Spectral Analysis', ...
     'FontSize',9, ...
     'Style','checkbox', ...
 	'Tag','Spectral', ...
     'TooltipString','Perform a LombPeriodogram Analysis of the Timeseries');
%	%'Position',[buttonxpos, byppn-8*bys*0.7, buttonx,byhp], ...
%	'Callback','gpsgui(''Spectral'')', ...
%	'FontSize',9,...
%	'String','Spectral Analysis', ...
%	'Tag','Spectral',...
%	'TooltipString','Click to perform spectral analysis using Lomb Periodogram');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% New options for file names
%
% Name of the edit file.  This ia pair of handles one with label, the other
% with the file name.  Since the text of fixed size we can set the second
% box position based on the first.
buttonn = buttony*0.95;
pos = [bdwidth*2+2,lbbot - buttonn, figsize(1)*0.1, buttonn*.75];
uicontrol('Parent',h0, ...
	'Position',pos, ...
	'String','Name of Edit File', ...
    'HorizontalAlignment','left', ...    
    'FontSize',9, ...
	'Style','text', ...
	'Tag','EdFileHead');
pos = [bdwidth*2+4, pos(2)-15 , figsize(1)*0.1, 22];
uicontrol('Parent',h0, ...
	'Position',pos, ...
    'HorizontalAlignment','left', ...
	'Style','edit',  ...
    'String','tsview.renames', ...
	'Tag','EditFile', ...
	'TooltipString','Name of the file created that saves the edits and breaks; use .brk extent to get Break command');
% Add two buttons.  One for Write and the other for erase
uicontrol('Parent',h0, ...
	'Position',[pos(1)-bdwidth*2 pos(2)+buttonn*0.5 28 15], ...
    'HorizontalAlignment','left', ...
	'Style','checkbox', ...
    'String','W', 'Value',1, ...
    'FontSize',9, ...
	'Tag','EdFileWrite', ...
	'TooltipString','Click to set file to be written on Save');
uicontrol('Parent',h0, ...
	'Position',[pos(1)-bdwidth*2 pos(2)+buttonn*0.1 28 15], ...
    'HorizontalAlignment','left', ...
	'Style','checkbox', ...
    'String','E', ...
    'FontSize',9, ...
    'Tag','EdFileErase', ...
	'TooltipString','Select to erase file before writing. Resets after any button use');

% Name of the output ensum summary file.
pos = [bdwidth*2+2,lbbot - 2.5*buttonn, figsize(1)*0.1, buttonn*.75];
uicontrol('Parent',h0, ...
	'Position',pos, ...
	'String','Output ENS File', ...
    'HorizontalAlignment','left', ...
    'FontSize',9, ...
	'Style','text', ...
	'Tag','EnFileHead');
pos = [bdwidth*2+4, pos(2)-15 , figsize(1)*0.1, 22];
uicontrol('Parent',h0, ...
	'Position',pos, ...
    'HorizontalAlignment','left', ...
	'Style','edit', ...
    'Value',1, ...
    'String','sutsview.ens', ...
	'Tag','ENSFile', ...
	'TooltipString','Name of the ensum summary file.  Entries added on SAVE');
% Add buttons to write and Erase
uicontrol('Parent',h0, ...
	'Position',[pos(1)-bdwidth*2 pos(2)+buttonn*0.5 28 15], ...
    'HorizontalAlignment','left', ...
	'Style','checkbox', ...
    'String','W', 'Value',1, ...
    'FontSize',9, ...
	'Tag','EnFileWrite', ...
	'TooltipString','Click to set file to be written on Save');
uicontrol('Parent',h0, ...
	'Position',[pos(1)-bdwidth*2 pos(2)+buttonn*0.1 28 15], ...
    'HorizontalAlignment','left', ...
	'Style','checkbox', ...
    'String','E', ...
    'FontSize',9, ...
    'Tag','EnFileErase', ...
	'TooltipString','Select to erase file before writing.  Resets after any button use');

% Name of the output Site details files.
pos = [bdwidth*2+2,lbbot - 4.0*buttonn, figsize(1)*0.1, buttonn*.75];
uicontrol('Parent',h0, 'Position',pos, ...
	'String','Root for Detail', ...
    'HorizontalAlignment','left', ...
    'FontSize',9, 'Style','text', ...
	'Tag','RtFileHead');
pos = [bdwidth*2+4, pos(2)-15 , figsize(1)*0.1, 22];
uicontrol('Parent',h0, 'Position',pos, ...
    'HorizontalAlignment','left', ...
	'Style','edit',  'String','ts_', ...
	'Tag','RtFile', ...
	'TooltipString','Root for site detail files');
% Add buttons to write and Erase
uicontrol('Parent',h0, ...
	'Position',[pos(1)-bdwidth*2 pos(2)+buttonn*0.5 28 15], ...
    'HorizontalAlignment','left', ...
	'Style','checkbox', 'String','W', 'Value',1, ...
    'FontSize',9,'Tag','RtFileWrite', ...
	'TooltipString','Click to set file to be written on Save');
uicontrol('Parent',h0, ...
	'Position',[pos(1)-bdwidth*2 pos(2)+buttonn*0.1 28 15], ...
    'HorizontalAlignment','left', ...
	'Style','checkbox',  'String','E', ...
    'FontSize',9,  'Tag','RtFileErase', ...
	'TooltipString','Select to erase file before writing.  Resets after any button use');

% Name of the input ENSUM file for sorting the stations.
pos = [bdwidth*2+2,lbbot - 5.5*buttonn, figsize(1)*0.1, buttonn*.75];
uicontrol('Parent',h0, 'Position',pos, ...
	'String','ENS file', ...
    'HorizontalAlignment','left', ...
    'FontSize',9, 'Style','text', ...
	'Tag','SrFileHead');
pos = [bdwidth*2+4, pos(2)-15 , figsize(1)*0.1, 22];
uicontrol('Parent',h0, 'Position',pos, ...
    'HorizontalAlignment','left', ...
	'Style','edit', 'String',[], ...
	'Tag','SrFile', ...
	'TooltipString','Ensum file for sorting site list');
% Add buttons to read and select sort by horizontal or Up RMS
uicontrol('Parent',h0, ...
	'Position',[pos(1)-bdwidth*2 pos(2)+buttonn*0.9 28 15], ...
    'HorizontalAlignment','left', ...
	'Style','checkbox', 'String','N', 'Value',1, ...
    'FontSize',9, 'Tag','SrNormal', ...
    'Callback','gpsgui(''Sort'')', ...
	'TooltipString','When set normalzied RMS used for sorting');
uicontrol('Parent',h0, ...
	'Position',[pos(1)-bdwidth*2 pos(2)+buttonn*0.5 28 15], ...
    'HorizontalAlignment','center', ...
	'Style','pushbutton', 'String','A', 'Value',1, ...
    'FontSize',9, 'Tag','SrSortAlph', ...
    'Callback','gpsgui(''Sort'')', ...
	'TooltipString','Click to sort sites Alphabetically');
uicontrol('Parent',h0, ...
	'Position',[pos(1)-bdwidth*2 pos(2)+buttonn*0.1 28 15], ...
    'HorizontalAlignment','center', ...
	'Style','pushbutton', 'String','H', 'Value',1, ...
    'FontSize',9, 'Tag','SrSortHorz', ...
    'Callback','gpsgui(''Sort'')', ...
	'TooltipString','Click to read ensum file and sort sites on Horizontal RMS');
uicontrol('Parent',h0, ...
	'Position',[pos(1)-bdwidth*2 pos(2)+buttonn*(-0.3) 28 15], ...
    'HorizontalAlignment','center', ...
	'Style','pushbutton', 'String','V', ...
    'FontSize',9, 'Tag','SrSortVert', ...
    'Callback','gpsgui(''Sort'')', ...
	'TooltipString','Click to read ensum file and sort sites on Vertical RMS');
uicontrol('Parent',h0, ...
	'Position',[pos(1)-bdwidth*2 pos(2)+buttonn*(-0.7) 28 15], ...
    'HorizontalAlignment','center', ...
	'Style','pushbutton', 'String','W', ...
    'FontSize',9, 'Tag','SrSortWorst', ...
    'Callback','gpsgui(''Sort'')', ...
	'TooltipString','Click to read ensum file and sort sites by worse component RMS');

% Name of the input earthquake file
pos = [bdwidth*2+2,lbbot - 7.0*buttonn, figsize(1)*0.1, buttonn*.75];
hu = uicontrol('Parent',h0, 'Position',pos, ...
	'String','GLOBK Eq file', ...
    'HorizontalAlignment','left', ...
    'FontSize',9, 'Style','text', ...
	'Tag','EqFileHead');
     set (hu,'UserData',saveeq);
pos = [bdwidth*2+4, pos(2)-15 , figsize(1)*0.1, 22];
uicontrol('Parent',h0, 'Position',pos, ...
    'HorizontalAlignment','left', ...
	'Style','edit', 'String',[], ...
	'Tag','EqFile', ...
	'TooltipString','GLOBK EQ file for breaks and editing');
uicontrol('Parent',h0, ...
	'Position',[pos(1)+figsize(1)*0.1, pos(2)+2+15 28 15], ...
    'HorizontalAlignment','center', ...
	'Style','pushbutton', 'String','L', ...
    'FontSize',9, 'Tag','LoadEqList', ...
    'Callback','gpsgui(''LoadEqList'')', ...
	'TooltipString','Click to load earthquake list');
uicontrol('Parent',h0, ...
	'Position',[pos(1)+figsize(1)*0.1, pos(2)+2 28 15], ...
    'HorizontalAlignment','center', ...
	'Style','pushbutton', 'String','C', ...
    'FontSize',9, 'Tag','ClrEqList', ...
    'Callback','gpsgui(''ClrEqList'')', ...
	'TooltipString','Click to clear file name; empty name and earthquakes/renames removed');


% Print dialog box.  Maybe improve later
pos = [bdwidth+5,5 , 65, buttonn*.75];
uicontrol('Parent',h0, 'Position',pos, ...
	'String','PageSetup', ...
    'HorizontalAlignment','left', ...
    'FontSize',9, 'Style','pushbutton', ...
    'Callback','gpsgui(''PageSetup'')', ...
	'Tag','PrintSetup', ...
    'TooltipString','Print set up dialog box');

pos = [bdwidth+70, 5 , 35, buttonn*.75];
uicontrol('Parent',h0, 'Position',pos, ...
	'String','Print', ...
    'HorizontalAlignment','left', ...
    'FontSize',9, 'Style','pushbutton', ...
    'Callback','gpsgui(''Print'')', ...
	'Tag','PrintButton', ...
    'TooltipString','Print dialog box');
pos = [bdwidth+105, 5 , 200, buttonn*.75];
uicontrol('Parent',h0, 'Position',pos, ...
	'String','Print', ...
    'HorizontalAlignment','left', ...
    'FontSize',9, 'Style','edit', 'String','-dpsc2', ...
	'Tag','PrintOpts', ...
    'TooltipString','Print options e.g., -P<printer>/filename -noui -r300');

% If a station name has been passed, label window as such
if selsite ~=0 
   outmes = sprintf('Plot generated for initially for %s',insite);
   uicontrol('Parent',h0, ...
    	'Units','pixels', ...
	    'Position',[bdwidth*2+310 5 250 15], ...
	    'String',outmes, ...
        'FontSize',9, ...
        'BackgroundColor',[.9 .9 .9], ...
        'ForegroundColor',[0 0 0], ...
	    'Style','text', ...
	    'Tag','SelSite');
    % Call GPSGUI to plot these data.
    gpsgui('Load',h0);
end    

drawnow
%hx = uicontrol('Parent',h0, ...
%	'Units','pixels', ...
%	'Position',[13 16 69 21], ...
%	'String',['North';'East ';'Up   '], ...
%	'Style','popupmenu', ...
%	'Tag','PopupMenu1', ...
%	'TooltipString','Select North. East or Up', ...
%	'Value',1);
if nargout > 0, fig = h0; end
