function CloseStats(save1,closesep)
% CloseStats: Report on statistics of close stations% Extract the velocity field and information from the save1 structure
vel1 = save1.Vel; name1 = save1.Name; vel1inf = save1.VellInf;

% Set up logical array which will be used to select sites
fid = fopen('Diff.vel','w');

dtr = pi/180;
ccs = cos(closesep/6371.0);
lims = [get(gca,'Xlim') get(gca,'Ylim')];
axx = [lims(1) lims(2) lims(2) lims(1) lims(1)];
axy = [lims(3) lims(3) lims(4) lims(4) lims(3)];
sitx = vel1(1,:); sity = vel1(2,:);
in1 = inpolygon(sitx, sity, axx, axy);
% Use only sites within current axes
vel1 = save1.Vel(:,in1); name1 = save1.Name(in1,:);
nd = length(vel1(1,:));
fprintf(1,'Statistics of %d sites in current view separated by less than %6.1f km\n', ...
    nd,closesep);
fprintf(fid,'Statistics of %d sites in current view separated by less than %6.1f km\n', ...
    nd,closesep);

EChi = 0; Ewgh = 0; NChi = 0; Nwgh = 0; UChi = 0; Uwgh = 0;
num = 0;
fprintf(1,'  Site2    Site1  Sep (km) East Diff  +-  North Diff +-  Up Diff   +-\n');

for i = 1:nd-1
    for j = i+1:nd
       
        % Velocities match see if within separation
        cosg =  sin(vel1(2,i)*dtr)*sin(vel1(2,j)*dtr) + ...
                cos(vel1(2,i)*dtr)*cos(vel1(2,j)*dtr)*cos((vel1(1,i)-vel1(1,j))*dtr);
        if cosg >= ccs
            % sites are close enough so report on difference
            dEv = vel1(3,j)-vel1(3,i); VE = vel1(7,j)^2+vel1(7,i)^2;
            dNv = vel1(4,j)-vel1(4,i); VN = vel1(8,j)^2+vel1(8,i)^2;
            dUv = vel1(10,j)-vel1(10,i); VU = vel1(12,j)^2+vel1(12,i)^2;
            EChi = EChi + (dEv^2/VE); Ewgh = Ewgh + 1./VE;
            NChi = NChi + (dNv^2/VN); Nwgh = Nwgh + 1./VN;
            UChi = UChi + (dUv^2/VU); Uwgh = Uwgh + 1./VU;
            num = num + 1;

            dist = acos(cosg)*6371.d0;
            fprintf('%s %s %6.2f    %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f\n', ...
                name1(j,:), name1(i,:), dist, dEv, sqrt(VE), dNv, sqrt(VN), dUv, sqrt(VU))
            fprintf(fid,' %8.3f %8.3f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.3f %6.2f %6.2f %6.2f %s\n', ...
                vel1([1 2],j),dEv, dNv, dEv, dNv, sqrt(VE), sqrt(VN), vel1(9,j), ...
                dUv, dUv, sqrt(VU), name1(j,:));
        end
    end
end

fclose(fid);

% Finish up the statistics
if num > 0 
    nrmsE = sqrt(EChi/num); wrmsE = nrmsE*sqrt(num/Ewgh);
    nrmsN = sqrt(NChi/num); wrmsN = nrmsN*sqrt(num/Nwgh);
    nrmsU = sqrt(UChi/num); wrmsU = nrmsU*sqrt(num/Uwgh);
    fprintf('For %d sites statistics are:\n',num);
    fprintf('EAST    WRMS %6.2f mm/yr; NRMS %6.3f\n',wrmsE, nrmsE);
    fprintf('NORTH   WRMS %6.2f mm/yr; NRMS %6.3f\n',wrmsN, nrmsN);
    fprintf('HEIGHT  WRMS %6.2f mm/yr; NRMS %6.3f\n',wrmsU, nrmsU);
else
    fprintf('No sites found\n');
end
    
