function ProfGUI(profxy, profname,profll,profaz)
% ProfGUI(profxy, profname): GUI for manipulating profile plots

% Pop a new figure window

% Get the range Along and cross track
da = [min(profxy(:,2)) max(profxy(:,2))];
dc = [min(profxy(:,4)) max(profxy(:,4))];
dt = [min(profxy(:,1)) max(profxy(:,1))];
dh = [min(profxy(:,6)) max(profxy(:,6))];
% Make sure that none of the ranges are exactly zero
if da(2)-da(1) <= 0, da = da + [-1 1]; end
if dc(2)-dc(1) <= 0, dc = dc + [-1 1]; end
if dh(2)-dh(1) <= 0, dh = dh + [-1 1]; end

totd = max([da(2)-da(1) dc(2)-dc(1)]);
dtr = [dt(1)-(dt(2)-dt(1))*0.05 dt(2)+(dt(2)-dt(1))*0.05];
dhr = [dh(1)-(dh(2)-dh(1))*0.05 dh(2)+(dh(2)-dh(1))*0.25];
% set axes to be the same
ax1 = [dtr (da(1)+da(2))/2-totd/1.95 (da(1)+da(2))/2+totd/1.75];
ax2 = [dtr (dc(1)+dc(2))/2-totd/1.95 (dc(1)+dc(2))/2+totd/1.75];
ax3 = [dtr dhr];

ScrnS = get(0,'ScreenSize'); wid = min(1240,ScrnS(3)); hgt = min(1024,ScrnS(4));
pos = [fix(wid/6) fix(hgt/3) fix(2*wid/3) fix(2*hgt/3)];
hpf = figure('Position',pos);

hpa1 = axes('Position',[.25 .703 .725 .23]);
he1 = errorbar(profxy(:,1),profxy(:,2),profxy(:,3),'bo');
set(he1,'MarkerSize',6,'MarkerFaceColor',[1 1 0],'Tag','ProfATData');
ylabel('Along Prof (mm/yr)');
axis(ax1);

% Now fit mean and trend to Along Track
[Wmean, CovM, Res, statm] = Wfit(profxy(:,1)-mean(profxy(:,1)),profxy(:,2),profxy(:,3),'1');
[Rate, CovR, Res, statr] = Wfit(profxy(:,1)-mean(profxy(:,1)),profxy(:,2),profxy(:,3),'1','x');
md = [ax1(1):(ax1(2)-ax1(1))/100:ax1(2)]; 
[LineT, sig] = Wmod(md-mean(profxy(:,1)),Rate, CovR,'1','x'); 
set(hpa1,'NextPlot','add','Tag','ProfAx1');
plot([ax1(1) ax1(2)],[Wmean Wmean],'r');
hl = plot(md,LineT,'k'); set(hl,'Tag','FitL1');
str = sprintf(['Wmean %6.2f +- %6.2f mm/yr; WRMS %6.1f mm/yr, NRMS %6.2f; %d sites\n', ...
        'Linear %6.3f +- %6.3f (mm/yr)/km;  WRMS %6.1f mm/yr, NRMS %6.2f'], ...
         Wmean, sqrt(CovM), statm([1 2 3]), Rate(2), sqrt(CovR(2,2)),statr([1 2]));
ht = text('String',str,'Tag','TextL1', ...
        'VerticalAlignment','bottom','Units','normalized',...
        'Position',[0.02 1.01 0],'FontSize',10);
% Write the projection Azimuth at the end of the line
str = sprintf('Azimuth %6.2f deg',profaz*180/pi);
ht = text('String',str, 'VerticalAlignment','bottom', ...
        'HorizontalAlignment','right','FontWeight','bold', 'Units','normalized',...
        'Position',[0.99 1.01 0],'FontSize',10);


% Set second set of axes for cross track
hpa2 = axes('Position',[.25 .395 .725 .23]);
he2 = errorbar(profxy(:,1),profxy(:,4),profxy(:,5),'bo');
set(he2,'MarkerSize',6,'MarkerFaceColor',[1 1 0],'Tag','ProfCTData');
ylabel('Cross Prof (mm/yr)')
axis(ax2);
% Now fit mean and trend to cross track data
[Wmean, CovM, Res, statm] = Wfit(profxy(:,1),profxy(:,4),profxy(:,5),'1');
[Rate, CovR, Res, statr] = Wfit(profxy(:,1)-mean(profxy(:,1)),profxy(:,4),profxy(:,5),'1','x');
md = [ax1(1):(ax1(2)-ax1(1))/100:ax1(2)]; 
[LineT, sig] = Wmod(md-mean(profxy(:,1)),Rate, CovR,'1','x'); 
set(hpa2,'NextPlot','add','Tag','ProfAx2');
plot([ax1(1) ax1(2)],[Wmean Wmean],'r');
hl = plot(md,LineT,'k'); set(hl,'Tag','FitL2');
str = sprintf(['Wmean %6.2f +- %6.2f mm/yr; WRMS %6.1f mm/yr, NRMS %6.2f; %d sites\n', ...
        'Linear %6.3f +- %6.3f (mm/yr)/km;  WRMS %6.1f mm/yr, NRMS %6.2f'], ...
         Wmean, sqrt(CovM), statm([1 2 3]), Rate(2), sqrt(CovR(2,2)),statr([1 2]));
ht = text('String',str,'Tag','TextL2', ...
        'VerticalAlignment','bottom','Units','normalized',...
        'Position',[0.02 1.01 0],'FontSize',10);
profnorm = profaz-pi/2;
if profnorm < -pi, profnorm = profnorm + 2*pi; end
str = sprintf('Azimuth %6.2f deg',profnorm*180/pi);
ht = text('String',str, 'VerticalAlignment','bottom', ...
        'HorizontalAlignment','right','FontWeight','bold', 'Units','normalized',...
        'Position',[0.99 1.01 0],'FontSize',10);



% Set up height axes
hpa3 = axes('Position',[.25 .087 .725 .23]);
he3 = errorbar(profxy(:,1),profxy(:,6),profxy(:,7),'bo');
set(he3,'MarkerSize',6,'MarkerFaceColor',[1 1 0],'Tag','ProfHTData');
ylabel('dH/dt (mm/yr)');xlabel('Distance along Profile (km)');
axis(ax3);
% Now fit mean and trend to height rates
[Wmean, CovM, Res, statm] = Wfit(profxy(:,1),profxy(:,6),profxy(:,7),'1');
[Rate, CovR, Res, statr] = Wfit(profxy(:,1)-mean(profxy(:,1)),profxy(:,6),profxy(:,7),'1','x');
md = [ax1(1):(ax1(2)-ax1(1))/100:ax1(2)]; 
[LineT, sig] = Wmod(md-mean(profxy(:,1)),Rate, CovR,'1','x'); 
set(hpa3,'NextPlot','add','Tag','ProfAx3');
plot([ax1(1) ax1(2)],[Wmean Wmean],'r');
hl = plot(md,LineT,'k');set(hl,'Tag','FitL3');
str = sprintf(['Wmean %6.2f +- %6.2f mm/yr; WRMS %6.1f mm/yr, NRMS %6.2f; %d sites\n', ...
        'Linear %6.3f +- %6.3f (mm/yr)/km;  WRMS %6.1f mm/yr, NRMS %6.2f'], ...
         Wmean, sqrt(CovM), statm([1 2 3]), Rate(2), sqrt(CovR(2,2)),statr([1 2]));
ht = text('String',str,'Tag','TextL3', ...
        'VerticalAlignment','bottom','Units','normalized',...
        'Position',[0.02 1.01 0],'FontSize',10);

% Set up the Profile structure and save in Figure handle
profstr = struct('Profxy',profxy,'ProfName',profname,'ProfLL',profll,'ProfAz',profaz);
% Save data in Figure Handle
set(hpf,'UserData',profstr);

%%%%%%%%%%%%%%%%%
% Now set up the GUI user iterface
pos = [0.01 0.93   0.07 0.035];
hl = uicontrol('Parent',hpf, ...
	        'Units','normalized', ...
	        'Position',pos, ...
            'FontSize',10, ...
	        'String','ID', ...
	        'Style','pushbutton', ...
	        'Tag','ProfID', ...
            'CallBack','ProfGUIcb(''ID'')', ...
            'UserData',[], ...
	        'TooltipString','Identify point on Profile');
pos = [0.09 0.93   0.07 0.035];
hl = uicontrol('Parent',hpf, ...
	        'Units','normalized', ...
	        'Position',pos, ...
            'FontSize',10, ...
	        'String','Delete', ...
	        'Style','pushbutton', ...
	        'Tag','ProfDelete', ...
            'CallBack','ProfGUIcb(''Delete'')', ...
	        'TooltipString','Delete point from Profile');

pos = [0.01 0.89   0.07 0.035];
hl = uicontrol('Parent',hpf, ...
	        'Units','normalized', ...
	        'Position',pos, ...
            'FontSize',10, ...
	        'String','Fit', ...
	        'Style','pushbutton', ...
	        'Tag','ProfFit', ...
            'CallBack','ProfGUIcb(''Fit'')', ...
	        'TooltipString','Fit function to Profile (see function boxes below');
pos = [0.09 0.89   0.07 0.035];
hl = uicontrol('Parent',hpf, ...
	        'Units','normalized', ...
	        'Position',pos, ...
            'FontSize',10, ...
	        'String','Save', ...
	        'Style','pushbutton', ...
            'BackgroundColor',[1 1 0.4], ...
	        'Tag','ProfSave', ...
            'CallBack','ProfGUIcb(''Save'')', ...
	        'TooltipString','Save information about profile in name below');
% Now do the file name for the save
pos = [0.01 0.84   0.15 0.035];
hl = uicontrol('Parent',hpf, ...
	        'Units','normalized', ...
	        'Position',pos, ...
            'FontSize',10, ...
            'HorizontalAlignment','left', ...
            'BackgroundColor',[1 1 0.4], ...
	        'String','File', ...
	        'Style','text', ...
	        'Tag','ProfFileTxt');
pos = [0.04 0.84   0.12 0.035];
hl = uicontrol('Parent',hpf, ...
	        'Units','normalized', ...
	        'Position',pos, ...
            'FontSize',10, ...
            'HorizontalAlignment','right', ...
            'BackgroundColor',[1 1 0], ...
	        'String',[], ...
	        'Style','edit', ...
	        'Tag','ProfSaveName', ...
	        'TooltipString','File name to save profile');
% Add a Plot residual button:        
pos = [0.01 0.80   0.07 0.035];
hl = uicontrol('Parent',hpf, ...
	        'Units','normalized', ...
	        'Position',pos, ...
            'FontSize',10, ...
	        'String','Residual', ...
	        'Style','pushbutton', ...
	        'Tag','ProfRes', ...
            'CallBack','ProfGUIcb(''ProfRes'')', ...
	        'TooltipString','Plot residuals to fit to profile');
        
% Now space for the functions to fit
pos = [0.01 0.54   0.15 0.24];
hl = uicontrol('Parent',hpf, ...
	        'Units','normalized', ...
	        'Position',pos, ...
            'FontSize',10, ...
            'HorizontalAlignment','center', ...
            'BackgroundColor',[.8 .6 1], ...
	        'String','Fitting Functions', ...
	        'Style','text', ...
	        'Tag','ProfFitFcn', ...
            'TooltipString','Enter functions for fitting e.g. 1/2+atan((x-100)/10)/pi or SS(100,10)');
% Box for the functions F1
pos = [0.011 0.705   0.148 0.038];
hl = uicontrol('Parent',hpf, ...
	        'Units','normalized', ...
	        'Position',pos, ...
            'FontSize',10, ...
            'HorizontalAlignment','left', ...
	        'String',[], ...
	        'Style','edit', ...
	        'Tag','FCN1', ...
            'TooltipString','Enter functions for fitting e.g. 1/2+atan((x-100)/10)/pi or SS(100,10)');
pos = [0.011 0.665   0.148 0.038];
hl = uicontrol('Parent',hpf, ...
	        'Units','normalized', ...
	        'Position',pos, ...
            'FontSize',10, ...
            'HorizontalAlignment','left', ...
	        'String',[], ...
	        'Style','edit', ...
	        'Tag','FCN2', ...
            'TooltipString','Enter functions for fitting e.g. SS(100,10) is atan form for executable');
pos = [0.011 0.627   0.148 0.038];
hl = uicontrol('Parent',hpf, ...
	        'Units','normalized', ...
	        'Position',pos, ...
            'FontSize',10, ...
            'HorizontalAlignment','left', ...
	        'String',[], ...
	        'Style','edit', ...
	        'Tag','FCN3', ...
            'TooltipString','Enter functions for fitting e.g. 1/2+atan((x-100)/10)/pi');
pos = [0.011 0.589   0.148 0.038];
hl = uicontrol('Parent',hpf, ...
	        'Units','normalized', ...
	        'Position',pos, ...
            'FontSize',10, ...
            'HorizontalAlignment','left', ...
	        'String',[], ...
	        'Style','edit', ...
	        'Tag','FCN4', ...
            'TooltipString','Enter functions for fitting e.g. 1/2+atan((x-100)/10)/pi');
pos = [0.011 0.551   0.148 0.038];
hl = uicontrol('Parent',hpf, ...
	        'Units','normalized', ...
	        'Position',pos, ...
            'FontSize',10, ...
            'HorizontalAlignment','left', ...
	        'String',[], ...
	        'Style','edit', ...
	        'Tag','FCN5', ...
            'TooltipString','Enter functions for fitting e.g. 1/2+atan((x-100)/10)/pi');




       

        
        
       
       


      



        
