function VelFigSet(option)
% VelFigSet: Set up the handles for the velocity figures
% Getsize of figure
hf = gcf ;
fullpos = get(hf,'Position');
%
% Compute the Figure size we want
figsize = [fullpos(3) fullpos(4)];

%
% Now start puting features on (or resizing)
% AXES
pos = fix([0.3*figsize(1) 0.05*figsize(2) 0.65*figsize(1) 0.9*figsize(2)]);
if strcmp(option,'Load') 
    axes('Parent',hf, ...
        'Color',[1 1 1], ...
        'Units','pixels', ...
        'Position',pos, ...
        'Tag','AxisVel', ...
        'Box','on', ...
	    'CameraUpVector',[0 1 0], ...
    	'Color',[1 1 1], ...
    	'XColor',[0 0 0], ...
	    'YColor',[0 0 0], ...
	    'ZColor',[0 0 0]);
%    hold on
%    plot([1 2 3],[3 5 6],'r-')
    drawnow
else
%    ha = gca 
%    get(ha)
    h1 = findobj(hf,'Tag','AxisVel');
    set(h1,'Position',pos);
%    h1
%    plot([1 2 4],[3 5 6],'bs-')
end


%%%%%%%%%
% Set up for file name inputs
bw = 0.2*figsize(1); bhn = 35; % Combined height of label and input box
lo = 0.02*figsize(2);          % Left offset from edge of figure
% We have four file names to fit in the top 25% of figure, Compute the
% spacing needed (25% for 4 Names with each name taking bhn space)
sp = figsize(2)*0.25/4 - bhn;

%-------- At the very top put a clear all buttom
pos = [lo 0.7*figsize(2)+3*(sp+bhn)+40 80 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','CLEAR ALL', ...
        'FontSize',10, 'FontWeight','bold', 'Style','pushbutton', ...
        'BackgroundColor',[1 0 0], ...
        'Callback','velgui(''ClearAll'')', ...
    	'Tag','ClearAll');
else
    h1 = findobj(hf,'Tag','ClearAll');
    set(h1,'Position',pos);
end

% Allow entry of the directory for the mb_ files
pos = [lo+90 0.7*figsize(2)+3*(sp+bhn)+40 80 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','TSeries DIR', ...
        'FontSize',10, 'Style','text', ...
    	'Tag','mbDIRLab');
else
    h1 = findobj(hf,'Tag','mbDIRLab');
    set(h1,'Position',pos);
end
pos = [lo+170 0.7*figsize(2)+3*(sp+bhn)+40 160 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String',[], ...
        'HorizontalAlignment','left', ...        
        'FontSize',10, 'Style','edit', ...
    	'Tag','mbDIR');
else
    h1 = findobj(hf,'Tag','mbDIR');
    set(h1,'Position',pos);
end


% Velocity file 1 (primary field)
pos = [lo 0.7*figsize(2)+3*(sp+bhn)+15 bw 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','Primary Velocity Field', ...
        'FontSize',10, 'Style','text', ...
    	'Tag','PrVelLabel');
else
    h1 = findobj(hf,'Tag','PrVelLabel');
    set(h1,'Position',pos);
end
pos = [lo 0.7*figsize(2)+3*(sp+bhn) bw 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
	    'Style','edit', 'Tag','VelName1', ...
    	'TooltipString','Name of primary velocity Field');
else
    h1 = findobj(hf,'Tag','VelName1');
    set(h1,'Position',pos);
end
% The Load button to Load the field
pos = [lo+bw pos(2) 30 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Load'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Load', 'Tag','LoadVel1', ...
    	'TooltipString','Click to load primary velocity field'); 
else
    h1 = findobj(hf,'Tag','LoadVel1');
    set(h1,'Position',pos);
end 
% The Clear button to Clear the field
pos = [lo+bw pos(2)+15 30 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Clear'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Clear', 'Tag','ClearVel1', ...
    	'TooltipString','Click to clear primary velocity field'); 
else
    h1 = findobj(hf,'Tag','ClearVel1');
    set(h1,'Position',pos);
end    
    
% Velocity file 2 (Secondary field)
pos = [lo 0.7*figsize(2)+2*(sp+bhn)+15 bw 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','Secondary Velocity Field', ...
        'FontSize',10, 'Style','text', ...
    	'Tag','ScVelLabel');
else
    h1 = findobj(hf,'Tag','ScVelLabel');
    set(h1,'Position',pos);
end
pos = [lo 0.7*figsize(2)+2*(sp+bhn) bw 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
	    'Style','edit', 'Tag','VelName2', ...
    	'TooltipString','Name of secondary velocity Field');
else
    h1 = findobj(hf,'Tag','VelName2');
    set(h1,'Position',pos);
end
% The Load button to Load the Secondary field
pos = [lo+bw pos(2) 30 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Load'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Load', 'Tag','LoadVel2', ...
    	'TooltipString','Click to load Secondary velocity field'); 
else
    h1 = findobj(hf,'Tag','LoadVel2');
    set(h1,'Position',pos);
end 
% The Clear button to Clear the field
pos = [lo+bw pos(2)+15 30 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Clear'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Clear', 'Tag','ClearVel2', ...
    	'TooltipString','Click to clear secondary velocity field'); 
else
    h1 = findobj(hf,'Tag','ClearVel2');
    set(h1,'Position',pos);
end    
    
% Ensum file (positions from the velocity fields)
pos = [lo 0.7*figsize(2)+1*(sp+bhn)+15 bw 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','ensum file', ...
        'FontSize',10, 'Style','text', ...
    	'Tag','ENSLabel');
else
    h1 = findobj(hf,'Tag','ENSLabel');
    set(h1,'Position',pos);
end
pos = [lo 0.7*figsize(2)+1*(sp+bhn) bw 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
	    'Style','edit', 'Tag','ENsName', ...
    	'TooltipString','Name of ENSUM file with velocities');
else
    h1 = findobj(hf,'Tag','ENsName');
    set(h1,'Position',pos);
end
% The Load button to Load the ENsum field
pos = [lo+bw pos(2) 30 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Load'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Load', 'Tag','LoadENs', ...
    	'TooltipString','Click to load ensum velocity field'); 
else
    h1 = findobj(hf,'Tag','LoadENs');
    set(h1,'Position',pos);
end 
% The Clear button to Clear the field
pos = [lo+bw pos(2)+15 30 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Clear'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Clear', 'Tag','ClearENs', ...
    	'TooltipString','Click to clear the ensum velocity field'); 
else
    h1 = findobj(hf,'Tag','ClearENs');
    set(h1,'Position',pos);
end    

% Output velocity file (All active velocity vectors are written)
pos = [lo 0.7*figsize(2)+0*(sp+bhn)+15 bw 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','Output Velocity File', ...
        'FontSize',10, 'Style','text', ...
    	'Tag','VelOutLabel');
else
    h1 = findobj(hf,'Tag','VelOutLabel');
    set(h1,'Position',pos);
end
pos = [lo 0.7*figsize(2)+0*(sp+bhn) bw 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
	    'Style','edit', 'Tag','VoutFile', ...
    	'TooltipString','Name of Output velocity File');
else
    h1 = findobj(hf,'Tag','VoutFile');
    set(h1,'Position',pos);
end
% The Save button to save the output field
pos = [lo+bw pos(2) 30 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Save'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Save', 'Tag','SaveVel', ...
    	'TooltipString','Click to Save all displayed velocities'); 
else
    h1 = findobj(hf,'Tag','SaveVel');
    set(h1,'Position',pos);
end 

% Now do the Features Dialog box (list of files for coastlines and faults
% (Name will probably used to decide on type of file).
% Need to think about these.   Will probably add a Load button and then
% selection on list entries to load.  One issue is how to remove names from
% the this list (next version).
pos = [lo 0.53*figsize(2)+0.15*figsize(2) bw 15];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','Feature Files', ...
        'FontSize',10, 'Style','text', ...
    	'Tag','FFileLabel');
else
    h1 = findobj(hf,'Tag','FFileLabel');
    set(h1,'Position',pos);
end
pos = [lo 0.53*figsize(2)+20 bw 0.15*figsize(2)-20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
	    'Units','pixels', ...
	    'BackgroundColor',[1 1 0.8], ...
	    'Position',pos, ...
	    'String',[], ...
	    'Style','listbox', ...
	    'Tag','FeatFiles', ...
	    'Value',0, ...
	    'UserData',[]) ;
else
    h1 = findobj(hf,'Tag','FeatFiles');
    set(h1,'Position',pos);
end
pos = [lo 0.53*figsize(2) bw 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
	    'Style','edit', 'Tag','FeatureEntry', ...
    	'TooltipString','Enter Names of feature files');
else
    h1 = findobj(hf,'Tag','FeatureEntry');
    set(h1,'Position',pos);
end
% Set up the load button.  Current features are simply to draw
% lines on the plot. Set up buttons for colors ClearFt
pos = [lo+bw pos(2) 40 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Feature'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','CLNm', 'Tag','ClearNm', ...
    	'TooltipString','Click to clear name (recommended once feature loaded)'); 
else
    h1 = findobj(hf,'Tag','ClearNm');
    set(h1,'Position',pos);
end
%
pos = [lo+bw pos(2)+15 40 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Feature'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','CLFt', 'Tag','ClearFt', ...
    	'TooltipString','Click to clear the selected feature plot'); 
else
    h1 = findobj(hf,'Tag','ClearFt');
    set(h1,'Position',pos);
end
% Black line 
pos = [lo+bw pos(2)+15 40 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Feature'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','LBlack', 'Tag','LoadFBk', ...
    	'TooltipString','Click to load named feature file with black line'); 
else
    h1 = findobj(hf,'Tag','LoadFBk');
    set(h1,'Position',pos);
end 
% Green line
pos = [lo+bw pos(2)+15 40 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Feature'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','LGreen', 'Tag','LoadFGr', ...
    	'TooltipString','Click to load named feature file with green line'); 
else
    h1 = findobj(hf,'Tag','LoadFGr');
    set(h1,'Position',pos);
end 
pos = [lo+bw pos(2)+15 40 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Feature'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','LYell', 'Tag','LoadFYe', ...
    	'TooltipString','Click to load named feature file with yellow line'); 
else
    h1 = findobj(hf,'Tag','LoadFYe');
    set(h1,'Position',pos);
end 
% Brown dots
pos = [lo+bw pos(2)+15 40 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Feature'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','DBrown', 'Tag','DotsFBr', ...
    	'TooltipString','Click to load named feature file brown dots'); 
else
    h1 = findobj(hf,'Tag','DotsFBr');
    set(h1,'Position',pos);
end 

% Main Program constrols:
pos = [lo 0.5*figsize(2) bw 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','Program Control', 'FontWeight','bold', 'BackgroundColor',[1 1 0],...
        'FontSize',10, 'Style','text', ...
    	'Tag','PConLabel');
else
    h1 = findobj(hf,'Tag','PConLabel');
    set(h1,'Position',pos); 
end
%
% Lat/log Limits entered by user.
pos = [lo 0.5*figsize(2)-1.0*(sp+bhn)+15 bw 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','Long/Lat limits', ...
        'FontSize',10, 'Style','text', ...
    	'Tag','LLLimLabel');
else
    h1 = findobj(hf,'Tag','LLLimLabel');
    set(h1,'Position',pos);
end
pos = [lo 0.5*figsize(2)-1.0*(sp+bhn) bw 20];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
	    'Style','edit', 'Tag','LLLimit', ...
    	'TooltipString','Long (min/max) Lat (min/max) Entry');
else
    h1 = findobj(hf,'Tag','LLLimit');
    set(h1,'Position',pos);
end
% The get button to copy the current long lat values from plot
pos = [lo+bw pos(2) 30 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''GetScale'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Get', 'Tag','GetScale', ...
    	'TooltipString','Get scales from current plot so that subsequent plots will have the same scale'); 
else
    h1 = findobj(hf,'Tag','GetScale');
    set(h1,'Position',pos);
end 
% Add a clear button
pos = [lo+bw pos(2)+15 30 15];
if strcmp(option,'Load')
   uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''ClearScale'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Clear', 'Tag','ClearScale', ...
    	'TooltipString','Clears values from scale box'); 
else
    h1 = findobj(hf,'Tag','ClearScale');
    set(h1,'Position',pos);
end 



%%--------------------------------------------------------
% Feqtures to be applied on Load of data sets. These are limits on sigmas
% scaling of the error bars and confidence ellipses.
% This group of buttons is of fixed size becuase they depend on the font
% size being used.
% bhn is for a box with label above.  For single box use half this.
LConColor = [0.73 1 0.27];
Lbot = 0.5*figsize(2)-(sp+bhn)-bhn*7.2/2; Ltop = Lbot + bhn*7/2;
pos = [lo Lbot bw bhn*7/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','Load Options      Horiz   Vert', ...
        'FontWeight','bold', ...
        'HorizontalAlignment','left', ...
        'BackgroundColor',LConColor,...
        'FontSize',10, 'Style','text', ...
    	'Tag','LConLabel', ...
        'ToolTipString','The boxes here control limits when fields are loaded');
else
    h1 = findobj(hf,'Tag','LConLabel');
    set(h1,'Position',pos);
end
% Sigma Limits.  Two boxes next to each other (horizontal and vertical).
% These need text and two edit boxes.
pos = [lo Ltop-2*bhn/2-3 bw bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','Sig Limit mm/yr', ...
        'HorizontalAlignment','left', ...
        'BackgroundColor',LConColor,...
        'FontSize',10, 'Style','text', ...
    	'Tag','LSigLabel');
else
    h1 = findobj(hf,'Tag','LSigLabel');
    set(h1,'Position',pos);
end
% Horizontal Option (Set default to 10 mm/yr)
posh = [pos(1)+0.5*bw pos(2)+3 bw/5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','right', ...
	    'Style','edit', 'Tag','SigHLim', ...
        'String','2', ...
    	'TooltipString','Limit on Horizontal velocity sigma to be loaded');
else
    h1 = findobj(hf,'Tag','SigHLim');
    set(h1,'Position',posh);
end
% Vertical Option (Set default to 10 mm/yr)
posh = [pos(1)+0.75*bw pos(2)+3 bw/5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','right', ...
	    'Style','edit', 'Tag','SigVLim', ...
        'String','5', ...
    	'TooltipString','Limit on Vertical velocity sigma to be loaded');
else
    h1 = findobj(hf,'Tag','SigVLim');
    set(h1,'Position',posh);
end

% Error bar scale for horizontal and Vertical
pos = [lo Ltop-3*bhn/2-3 bw bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','Error Scaling', ...
        'HorizontalAlignment','left', ...
        'BackgroundColor',LConColor, ...
        'FontSize',10, 'Style','text', ...
    	'Tag','LEScLabel');
else
    h1 = findobj(hf,'Tag','LEScLabel');
    set(h1,'Position',pos);
end
% Horizontal Scaling
posh = [pos(1)+0.5*bw pos(2)+3 bw/5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','right', ...
	    'Style','edit', 'Tag','SigHScl', ...
        'String','1', ...
    	'TooltipString','Horizontal velocity sigma scaling on load before scaling');
else
    h1 = findobj(hf,'Tag','SigHScl');
    set(h1,'Position',posh);
end
% Vertical Scaling
posh = [pos(1)+0.75*bw pos(2)+3 bw/5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','right', ...
	    'Style','edit', 'Tag','SigVScl', ...
        'String','1', ...
    	'TooltipString','Vertical velocity sigma scaling on load before scaling');
else
    h1 = findobj(hf,'Tag','SigVScl');
    set(h1,'Position',posh);
end

% Confidence intervals to be plotted
pos = [lo Ltop-4*bhn/2-3 bw bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','Confidence Int %', ...
        'HorizontalAlignment','left', ...
        'BackgroundColor',LConColor, ...
        'FontSize',10, 'Style','text', ...
    	'Tag','LCniLabel');
else
    h1 = findobj(hf,'Tag','LCniLabel');
    set(h1,'Position',pos);
end
% Horizontal confidence interval 
posh = [pos(1)+0.5*bw pos(2)+3 bw/5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','right', ...
	    'Style','edit', 'Tag','ConfidH', ...
        'String','95', ...
    	'TooltipString','Horizontal Error ellipse confidence interval');
else
    h1 = findobj(hf,'Tag','ConfidH');
    set(h1,'Position',posh);
end
% Vertical confidence interval 
posh = [pos(1)+0.75*bw pos(2)+3 bw/5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','right', ...
	    'Style','edit', 'Tag','ConfidV', ...
        'String','68', ...
    	'TooltipString','Vertical  Error bar confidence interval');
else
    h1 = findobj(hf,'Tag','ConfidV');
    set(h1,'Position',posh);
end

% Length of vectors (1 is 1-to-1 scaling, 2 would be twice as long
pos = [lo Ltop-5*bhn/2-3 bw bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','Arrow length', ...
        'HorizontalAlignment','left', ...
        'BackgroundColor',LConColor, ...
        'FontSize',10, 'Style','text', ...
        'UserData',[],  'Tag','LAlnLabel');
else
    h1 = findobj(hf,'Tag','LAlnLabel');
    set(h1,'Position',pos);
end
% Horizontal confidence interval 
posh = [pos(1)+0.5*bw pos(2)+3 bw/5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','right', ...
	    'Style','edit', 'Tag','ArrowH', ...
        'String','1.0', ...
    	'TooltipString','Scaling for horizontal vector (1.0 true scale)');
else
    h1 = findobj(hf,'Tag','ArrowH');
    set(h1,'Position',posh);
end
% Vertical confidence interval 
posh = [pos(1)+0.75*bw pos(2)+3 bw/5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','right', ...
	    'Style','edit', 'Tag','ArrowV', ...
        'String','1.0', ...
    	'TooltipString','Scaling for vertical vector (1.0 true scale)');
else
    h1 = findobj(hf,'Tag','ArrowV');
    set(h1,'Position',posh);
end

% Arrow head size (only for Horizontal)
pos = [lo Ltop-6*bhn/2-3 bw bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','Arrow Head Size', ...
        'HorizontalAlignment','left', ...
        'BackgroundColor',LConColor, ...
        'FontSize',10, 'Style','text', ...
    	'Tag','AHeadSLab');
else
    h1 = findobj(hf,'Tag','AHeadSLab');
    set(h1,'Position',pos);
end
% Horizontal arrow head size
posh = [pos(1)+0.5*bw pos(2)+3 bw*0.45 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','right', ...
	    'Style','popupmenu', 'Tag','ArhHLimit', ...
        'String',['None  ';'0.5 mm';'1.0 mm';'1.5 mm';'2.0 mm';'3.0 mm'], ...
        'Value',3, ...
    	'TooltipString','Horizontal Vector arrow head size');
else
    h1 = findobj(hf,'Tag','ArhHLimit');
    set(h1,'Position',posh);
end

% Push buttons to say if Horizontal and or vertical should be shown
pos = [lo Ltop-7*bhn/2-3 bw bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
    	'String','Display', ...
        'HorizontalAlignment','left', ...
        'BackgroundColor',LConColor, ...
        'FontSize',10, 'Style','text', ...
    	'Tag','LDisLabel');
else
    h1 = findobj(hf,'Tag','LDisLabel');
    set(h1,'Position',pos);
end
% Display horizontal velocities
posh = [pos(1)+0.5*bw pos(2)+3 bw/5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','right', ...
	    'Style','checkbox', 'Tag','DisplayH', ...
        'String','H', 'Value',1,  ...
    	'TooltipString','Select to display horizontal velocities');
else
    h1 = findobj(hf,'Tag','DisplayH');
    set(h1,'Position',posh);
end

% Display Vertical Velocities
posh = [pos(1)+0.75*bw pos(2)+3 bw/5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','right', ...
	    'Style','checkbox', 'Tag','DisplayV', ...
        'String','V', 'Value',0, ...
    	'TooltipString','Select to display vertical velocities');
else
    h1 = findobj(hf,'Tag','DisplayV');
    set(h1,'Position',posh);
end
% Display Names
posh = [pos(1)+0.25*bw pos(2)+3 bw/5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','right', ...
	    'Style','checkbox', 'Tag','DisplayN', ...
        'String','N', 'Value',1,  ...
    	'TooltipString','Select to display 4-char station names');
else
    h1 = findobj(hf,'Tag','DisplayN');
    set(h1,'Position',posh);
end

% Directional arrows to allow pannning (position relative to Display line)
posc = [pos(1)+bw+12 pos(2)+15 15 15];  % Center of button cluster
bgc = [.9 .9 1];
% Background color
posh = [posc(1)-15 posc(2)-10 45 50];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','center', ...
	    'Style','text', 'Tag','PanCon', ...
        'String','Pan',  'BackgroundColor',[0.5 .9 1], ...
    	'TooltipString','Pan controls');
else
    h1 = findobj(hf,'Tag','PanCon');
    set(h1,'Position',posh);
end

    
% Left pan (-20,+20)
posh = [posc(1)-15 posc(2) posc(3) posc(4)];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','center', ...
	    'Style','pushbutton', 'Tag','PanL', ...
        'callback','velgui(''Pan'')', ...
        'String','<',  'BackgroundColor',bgc, ...
    	'TooltipString','Pan left by half map width');
else
    h1 = findobj(hf,'Tag','PanL');
    set(h1,'Position',posh);
end
% Right pan (+20,+20)
posh = [posc(1)+15 posc(2) posc(3) posc(4)];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','center', ...
	    'Style','pushbutton', 'Tag','PanR', ...
        'callback','velgui(''Pan'')', ...
        'String','>',  'BackgroundColor',bgc, ...
    	'TooltipString','Pan right by half map width');
else
    h1 = findobj(hf,'Tag','PanR');
    set(h1,'Position',posh);
end
% Zoom out by doubling figure size
posh = [posc(1) posc(2) posc(3) posc(4)];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','center', ...
	    'Style','pushbutton', 'Tag','PanO', ...
        'callback','velgui(''Pan'')', ...
        'String','-',  'BackgroundColor',bgc, ...
    	'TooltipString','Increase viewing area by 50%');
else
    h1 = findobj(hf,'Tag','PanO');
    set(h1,'Position',posh);
end

% Up pan (0,+40)
posh = [posc(1) posc(2)+15 posc(3) posc(4)];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','center', ...
	    'Style','pushbutton', 'Tag','PanU', ...
        'callback','velgui(''Pan'')', ...
        'String','^',  'BackgroundColor',bgc, ...
    	'TooltipString','Pan up by half map height');
else
    h1 = findobj(hf,'Tag','PanU');
    set(h1,'Position',posh);
end
% Down pan (0,-40)
posh = [posc(1) posc(2)-15 posc(3) posc(4)];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','center', ...
	    'Style','pushbutton', 'Tag','PanD', ...
        'callback','velgui(''Pan'')', ...
        'String','v',  'BackgroundColor',bgc, ...
    	'TooltipString','Pan down by half map height');
else
    h1 = findobj(hf,'Tag','PanD');
    set(h1,'Position',posh);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Action buttons at the bottom of the plot
%
Ltop = Lbot;
% We have four lines of buttons to add.
pos = [lo Ltop-bhn/2 bw/2.8 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Zoomin'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Zoom In', 'Tag','ZoomIn', ...
    	'TooltipString','Zoom by dragging across area, Vectors also zoom');
else
    h1 = findobj(hf,'Tag','ZoomIn');
    set(h1,'Position',pos);
end
% Next button on line
posh =[pos(1)+bw/2.7 pos(2) pos(3) pos(4)];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Zoomout'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Zoom Out', 'Tag','ZoomOut', ...
    	'TooltipString','Zooms back through zoom in steps');
else
    h1 = findobj(hf,'Tag','ZoomOut');
    set(h1,'Position',posh);
end
% Next button on line
posh =[pos(1)+2*bw/2.7 pos(2) pos(3) pos(4)];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Redraw'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Redraw', 'Tag','Redraw', ...
    	'TooltipString','Redraws with new arrow length, ConFid');
else
    h1 = findobj(hf,'Tag','Redraw');
    set(h1,'Position',posh);
end
% Set of Vector Zoom buttons: These zoom and keep the vectors the same
% length (handled in the same call back).
pos = [lo Ltop-2*bhn/2 pos(3) pos(4)];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Zoomin'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','VecZoomIn', 'Tag','VecZoomIn', ...
    	'TooltipString','Zoom by dragging across area, Vectors stay the same length');
else
    h1 = findobj(hf,'Tag','VecZoomIn');
    set(h1,'Position',pos);
end
% Next button on line
posh =[pos(1)+bw/2.7 pos(2) pos(3) pos(4)];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Zoomout'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','VecZoomOut', 'Tag','VecZoomOut', ...
    	'TooltipString','Zooms out back through Vec Zoom in steps');
else
    h1 = findobj(hf,'Tag','VecZoomOut');
    set(h1,'Position',posh);
end
% Next button on line: Clear zoom buttons
posh =[pos(1)+2*bw/2.7 pos(2) pos(3) pos(4)];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''ClearZoom'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Clear Zoom', 'Tag','ClearZoom', ...
    	'TooltipString','Clears the zoom stack; both regular and vector');
else
    h1 = findobj(hf,'Tag','ClearZoom');
    set(h1,'Position',posh);
end
% Profile button.  
pos = [lo Ltop-3*bhn/2 bw/3.5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Profile'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Profile', 'Tag','Profile', ...
    	'TooltipString','Selection of profile line');
else
    h1 = findobj(hf,'Tag','Profile');
    set(h1,'Position',pos);
end

% Put in buttons to pop the top and bottom of the profile stacks
posh = [lo+bw/3.5 pos(2) bw/6 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','center', ...
        'Callback','velgui(''ProfPop'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','POP', 'Tag','ProfPop', ...
        'UserData',[], ...
    	'TooltipString','Remove the last profile from the plot');
else
    h1 = findobj(hf,'Tag','ProfPop');
    set(h1,'Position',posh);
end
posh = [lo+bw/3.5+bw/6 pos(2) bw/6 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','center', ...
        'Callback','velgui(''ProfPop'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','PIP', 'Tag','ProfPip', ...
        'UserData',[], ...
    	'TooltipString','Remove initial profile from the plot');
else
    h1 = findobj(hf,'Tag','ProfPip');
    set(h1,'Position',posh);
end
posh = [lo+bw/3.5+2*bw/6 pos(2) bw/6 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''ProfAz'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','AZ', 'Tag','ProfAz', ...
        'UserData',[], ...
    	'TooltipString','Set Azimuth for profile projection (graphical or using value in box)');
else
    h1 = findobj(hf,'Tag','ProfAz');
    set(h1,'Position',posh);
end
posh = [lo+bw/3.5+3*bw/6 pos(2) bw/3 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',posh, ...
        'HorizontalAlignment','right', ...
        'FontSize',9, ...
	    'Style','edit', 'String',[], 'Tag','ProfAzIn', ...
        'UserData',[], ...
    	'TooltipString','Type azimuth for velocity projection (deg)');
else
    h1 = findobj(hf,'Tag','ProfAzIn');
    set(h1,'Position',posh);
end


% Remove offset
pos = [lo Ltop-4*bhn/2 bw/3.5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Offset'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Offset', 'Tag','Offset', ...
    	'TooltipString','If no values are in box, then select area to demean');
else
    h1 = findobj(hf,'Tag','Offset');
    set(h1,'Position',pos);
end
pos = [lo+bw/3 pos(2) bw*0.65 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','right', ...
	    'Style','edit', 'Tag','Offvalue', ...
        'String',[], ...
    	'TooltipString','Enter offset here (dVe dVn) and select Offset');
else
    h1 = findobj(hf,'Tag','Offvalue');
    set(h1,'Position',pos);
end
% Add a clear button
pos = [lo+bw pos(2)+2 30 15];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''ClearOff'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Clear', 'Tag','ClearOffset', ...
    	'TooltipString','Clears values in offset box');
else
    h1 = findobj(hf,'Tag','ClearOffset');
    set(h1,'Position',pos);
end

% Align secondary field to the primary 
pos = [lo Ltop-5*bhn/2 bw/3.5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''Align'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Align', 'Tag','Align', ...
    	'TooltipString','If no values are in box, then select area to align the secondary field to primary');
else
    h1 = findobj(hf,'Tag','Align');
    set(h1,'Position',pos);
end
pos = [lo+bw/3 pos(2) bw*0.65 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','right', ...
	    'Style','edit', 'Tag','Alignvalue', ...
        'String',[], ...
    	'TooltipString','Enter aligment here (dVe dVn dVu) and select Align');
else
    h1 = findobj(hf,'Tag','Alignvalue');
    set(h1,'Position',pos);
end
% Add a clear button
pos = [lo+bw pos(2)+2 30 15];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''ClearAlign'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Clear', 'Tag','ClearAlign', ...
    	'TooltipString','Clears values in alignment box');
else
    h1 = findobj(hf,'Tag','ClearAlign');
    set(h1,'Position',pos);
end

% Statistics and miscelaneous buttons
pos = [lo Ltop-6*bhn/2 bw/3.5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''RmDups'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','RmDups', 'Tag','RmDups', ...
    	'TooltipString','Remove duplicates from velocities based on separation');
else
    h1 = findobj(hf,'Tag','RmDups');
    set(h1,'Position',pos);
end
pos = [lo+bw/3.5 pos(2) bw/3.5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''CloseStats'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Stats', 'Tag','CloseStats', ...
    	'TooltipString','Statistics of sites separated by separation');
else
    h1 = findobj(hf,'Tag','CloseStats');
    set(h1,'Position',pos);
end

pos = [lo+2*bw/3.35 pos(2) bw*0.30 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','right', ...
	    'Style','edit', 'Tag','CloseSep', ...
        'String','1.0', ...
    	'TooltipString','Enter separation of sites for statistics (e.g., 1.0 km)');
else
    h1 = findobj(hf,'Tag','CloseSep');
    set(h1,'Position',pos);
end
pos = [lo+2*bw/3.35+bw*0.3 pos(2) 30 bhn/2.5];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
	    'Style','text', 'Tag','CloseUnits', ...
        'String','km');
else
    h1 = findobj(hf,'Tag','CloseUnits');
    set(h1,'Position',pos);
end

% Button to Identify points (lists the information about close points) 
pos = [lo Ltop-7*bhn/2 bw/3.5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''IDPoints'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','ID Points', 'Tag','IDpts', ...
    	'TooltipString','Lists sites in drag and click region');
else
    h1 = findobj(hf,'Tag','IDpts');
    set(h1,'Position',pos);
end
% Button to swap the primary and secondary velocity fields
pos = [lo+bw/3.5 Ltop-7*bhn/2 bw/3.5 bhn/2];
if strcmp(option,'Load')
    uicontrol('Parent',hf, ...
    	'Position',pos, ...
        'HorizontalAlignment','left', ...
        'Callback','velgui(''SWAP'')', ...
        'FontSize',9, ...
	    'Style','pushbutton', 'String','Swap', 'Tag','SWAP', ...
    	'TooltipString','Swap the primary and secondary fields');
else
    h1 = findobj(hf,'Tag','SWAP');
    set(h1,'Position',pos);
end

% Print dialog box.  Maybe improve later
pos = [lo,5 ,55, 18];
if strcmp(option,'Load')
    uicontrol('Parent',hf, 'Position',pos, ...
        'String','PageSetup', ...
        'HorizontalAlignment','left', ...
        'FontSize',9, 'Style','pushbutton', ...
        'Callback','velgui(''PageSetup'')', ...
        'Tag','PrintSetup', ...
        'TooltipString','Print set up dialog box');
else
    h1 = findobj(hf,'Tag','PrintSetup');
    set(h1,'Position',pos);
end
    
pos = [lo+58, 5 , 30, 18];
if strcmp(option,'Load')
    uicontrol('Parent',hf, 'Position',pos, ...
        'String','Print', ...
        'HorizontalAlignment','left', ...
        'FontSize',9, 'Style','pushbutton', ...
        'Callback','velgui(''Print'')', ...
        'Tag','PrintButton', ...
        'TooltipString','Print dialog box');
else
    h1 = findobj(hf,'Tag','PrintButton');
    set(h1,'Position',pos);
end

pos = [lo+90, 5 , 150, 18];
if strcmp(option,'Load')
    uicontrol('Parent',hf, 'Position',pos, ...
	'String','Print', ...
    'HorizontalAlignment','left', ...
    'FontSize',10, 'Style','edit', 'String','-dpsc2', ...
	'Tag','PrintOpts', ...
    'TooltipString','Print options e.g., -P<printer>/filename -noui -r300');
else
    h1 = findobj(hf,'Tag','PrintOpts');
    set(h1,'Position',pos);
end


