function VelRedraw(ha, limo, limn, veczoom)
% VelRedraw: Redraws a map with new parameters:
% Vectors need to be rescaled for the new axis and we need to hide things
% that no longer appear on the plot.
% veczoom is true if vectors are to remain the same length when zoomed

% Rescale the axes
set(ha,'XLim',limn(1:2)); set(ha,'YLim',limn(3:4));

[sno,cmlo] = VelScale(ha,limo); [snn,cmln] = VelScale(ha,limn);

% Get the current arrow length.
hah = findobj(gcf,'Tag','ArrowH');
arrowHo = str2num(get(hah,'String'));
hav = findobj(gcf,'Tag','ArrowV');
arrowVo = str2num(get(hav,'String'));

% If this is a regular zoom, we will scale the arrow lengths so that they
% increase as you zoom in.
if ~veczoom 
    arrmul = (sno(1)/snn(1)+sno(2)/snn(2))/2;
    % To ensure that we can get back through the sequence of zooms, compute
    % the new arrow lengths and write to the string that will save them.
    % Read back the string and use that values.
    arrstr = sprintf('%8.2f',arrowHo*arrmul); arrowHn = str2num(arrstr); 
    arrmul = arrowHn/arrowHo;
    arrowHn = arrowHo*arrmul; arrowVn = arrowVo*arrmul;
    % Put the values back in the box
    set(hah,'String',sprintf('%8.2f',arrowHn));
    set(hav,'String',sprintf('%8.2f',arrowVn));
    % Finally make the scale consistent with the arrowlength
    snn = snn*arrmul;
end

% Get the children of the current current axes.
ho = get(ha,'Children');

% Loop over the children, scaling for the type
for i = 1:length(ho)
    type = get(ho(i),'Type'); ut = get(ho(i),'Tag');
    if strcmp(type,'line') & strcmp(ut,'GPSH')
        xd = get(ho(i),'Xdata'); yd = get(ho(i),'Ydata');
        % Now scale the difference from the first point
        xd = xd - (xd-xd(1))*(1-snn(1)/sno(1));
        yd = yd - (yd-yd(1))*(1-snn(2)/sno(2));
        set(ho(i),'Xdata',xd); set(ho(i),'Ydata',yd);
    end
    if strcmp(type,'line') & strcmp(ut,'GPSV')
        xd = get(ho(i),'Xdata'); yd = get(ho(i),'Ydata');
        % Now scale the difference from the first point
        xd = xd - (xd-xd(1))*(1-snn(1)/sno(1));
        yd = yd - (yd-yd(1))*(1-snn(2)/sno(2));
        set(ho(i),'Xdata',xd); set(ho(i),'Ydata',yd);
    end
    if strcmp(type,'line') & strcmp(ut,'VERR')
        % Get the User data so that we can get the start lat and long
        ud = get(ho(i),'UserData'); sitell = ud.Pos;
        xd = get(ho(i),'Xdata'); yd = get(ho(i),'Ydata');
        % Get the height latitude (point 3 and 4 are on the center of the
        % error bar)
        hlat = (yd(3)+yd(4))/2; hnew = sitell(2) + (hlat-sitell(2))/sno(2)*snn(2);
        % Move the error bar
        xd = xd - (xd-xd(3))*(1-snn(1)/sno(1));
        yr = yd - [hlat hlat hlat hlat hlat hlat];
        yd = [hnew hnew hnew hnew hnew hnew] + yr/sno(2)*snn(2);
        set(ho(i),'Xdata',xd); set(ho(i),'Ydata',yd);
    end
        
    if strcmp(type,'rectangle')
        % Get the user data which contains the original starting point
        ud = get(ho(i),'UserData'); sitell = ud.Pos;
        rp = get(ho(i),'Position');
        % sitell = get(ho(i),'UserData');
        if ~isempty(sitell)     % Make sure we have in case someother rectangle
            % Now scale the difference from the center of rectangle
            % Get the center of rectangle
            rc = [rp(1)+rp(3)/2 rp(2)+rp(4)/2];
            vel = (rc-sitell)./sno ;  % Original velocity
            dll = vel.*snn ;          % New long lat difference
            rn = [sitell(1)+dll(1)-rp(3)*snn(1)/sno(1)/2 ...
                  sitell(2)+dll(2)-rp(4)*snn(2)/sno(2)/2 ... 
                 rp(3)*snn(1)/sno(1) rp(4)*snn(2)/sno(2)];
            set(ho(i),'Position',rn);
        end
    end
end   % Loop over the children
    
% Get the mean latidue and reset the aspect ratio
set(ha,'DataAspectRatio',[1 cmln 1]);
    
        
        