function [Est, Cov, res, stat] = Wfit(t, obs, sig, varargin)
% [Est, Cov, res, stat] = Wfit(ind, obs,sig, vargin) Weight fit based on
% functions passed
% Construct the funtions passed (Functions are allowed to be empty and just
% do not get counted.
% Some functions are evaluated with out usinf inline so that they will work
% in the executable version.  These functions are '1' 'x' and SS(P,D) which
% implements a strike-slip atan formula for position P along profile and
% Depth D.
if nargin == 3,  part{1} = '1'; np = 1;  % Assume just a mean wanted (same as '1' for forth argument
else
    np = 0;
    for i = 1:nargin-3
        if ~isempty(varargin{i})
            np = np + 1;
            % For the simple x function just use straight function which
            % will run in the executable version
            if char(varargin{i}) == '1', part{i} = '1';
            elseif char(varargin{i}) == 'x', part{np} = 'x';
            elseif strncmp('SS',char(varargin{i}),2), part{np} = SSparse(char(varargin{i}));
            else part{np} = inline(char(varargin{i}));
            end
        end
    end
end
%
% Setup the partials array
nd = length(t);
A = [];
for i = 1:nd
    at = [];
    for j = 1:np
        if char(part{j}) == '1', at = [at, 1]; 
        elseif char(part{j}) == 'x', at = [at, t(i)];
        elseif strncmp('SS', char(part{j}),2)
            at = [at, SSeval(char(part{j}),t(i))];
        else at = [at, feval(part{j},t(i))];
        end
    end
    A = [A; at];
end
%
% Generate inverse covariance matrix
ss = size(sig); if ss(1) == 1; sig = sig'; end
w = 1./sig.^2;
% Form Normal equations
for i = 1:np
    Atw(:,i) = A(:,i).*w;
end
Atw = Atw';
N = Atw*A;
% Get direction of obs (row or column)
so = size(obs); if so(1) == 1; obs = obs'; end
b = Atw*obs;
Cov = inv(N); Est = Cov*b;
res = obs - A*Est;
% Finally complete the stats
if nd-np > 0
    nrms = sqrt(sum(res'.^2.*w')/(nd-np));
else
    nrms = 1.0;
end
wrms = nrms*sqrt(nd/sum(w));
stat = [wrms nrms nd];
