function velgui(option,cbname, num,fld)
% VELGUI: Main GUI interface for velview
% Option is the option passed back from the GUI and is handled with the
% case statements below;
% cbname if the name of site from the callback:
% num is optional site number from field 1-3 where 1=VelName1, 2=VelName3
% and 3=EnsName

% Get the handles as to how we got here
% fprintf('Entered velgui Option %s \n',option)
[hcb hf] = gcbo;  % Handle to callback object and associated figure
ha = gca;         % Handle to axes for plot

% Get the current scales from the scale bax (LLLimit tag)
hs = findobj(hf,'Tag','LLLimit');
scalestr = get(hs,'String');
if ~isempty(scalestr)
    llsize = sscanf(scalestr,'%f %f %f %f');
else
    llsize = [];
end

%%%%%%%%%%%%%%%%%%%%
% Handle the GUI interface through a switch 

switch(option)
    
    % Clear all graphics and start again
    case 'ClearAll'
        % Delete all the childrean of the current axes
        hc = get(ha,'Children');
        delete(hc);
    
    % Load Velocity Field
    case 'Load'
        % Get which field from the tag on the callback object
        % fprintf('Loading')
        velclass = get(hcb,'Tag');
        % If handles already exist for this plot, delete all the graphics
        % objects first
        ClearHandles(hcb);
                    
        if strcmp(velclass,'LoadVel1')
            % Get the object with the file name and infotmation about this
            % data set load and plot
            vel1inf = getVelinf(hf, 'VelName1');
            if isempty(vel1inf.FileName), errordlg('No Primary Velocity Field File Name');
            else
                % Readin the field and plot
                [vel1, name1] = ReadVel(vel1inf);
                [offs, aligns] = GetOffset(hf);
                vel1n = vel1;
                vel1n(3,:) = vel1n(3,:) - offs(1);
                vel1n(4,:) = vel1n(4,:) - offs(2);
                
                % Set the arrow characters based on Primary and parameters
                arrowstr = GenArrowStr(1);
                hndlh1 = Hplot(ha,name1,vel1n,llsize,vel1inf,arrowstr);
                % Save the handles so that we can delete or change later
                set(hcb,'UserData',hndlh1);
            end
            %
            % Now we need to store the data back in the VelName1 handle
            hn = findobj(hf,'Tag','VelName1');
            save1 = struct('Vel',vel1,'Name',name1,'VellInf',vel1inf);
            set(hn,'UserData',save1);
            
            % Finally report the number of stations shown on plot
            ReportNum(vel1);
            
        end     % if Load of velocity 1
        
        if strcmp(velclass,'LoadVel2')
            % Get the object with the file name and infotmation about this
            % data set load and plot
            vel2inf = getVelinf(hf, 'VelName2');
            
            if isempty(vel2inf.FileName), errordlg('No Secondary Velocity Field File Name');
            else
                % Readin the field and plot
                [vel2, name2] = ReadVel(vel2inf);
                [offs, aligns] = GetOffset(hf);
                vel2n = vel2;
                vel2n(3,:) = vel2(3,:) - offs(1) - aligns(1); 
                vel2n(4,:) = vel2(4,:) - offs(2) - aligns(2);
                vel2n(10,:) = vel2n(10,:) - aligns(3);
                % Set the arrow characters based on Primary and parameters
                arrowstr = GenArrowStr(2);
                llsize = [get(ha,'Xlim') get(ha,'Ylim')];
                hndlh2 = Hplot(ha,name2,vel2n,llsize,vel2inf,arrowstr);
                % Save the handles so that we can delete or change later
                set(hcb,'UserData',hndlh2);
            end
            %
            % Now we need to store the data back in the VelName1 handle
            hn = findobj(hf,'Tag','VelName2');
            save2 = struct('Vel',vel2,'Name',name2,'VellInf',vel2inf);
            set(hn,'UserData',save2);
            
            % Finally report the number of stations shown on plot
            ReportNum(vel2);
        end     % if Load of velocity 1
        % Put scale arrows on plot
        ShowArrow(hf,ha);
        
    case 'Clear'
        % Get which field from the tag on the callback object
        cleartag = get(hcb,'Tag');
        % If handles already exist for this plot, delete all the graphics
        % objects first
        savetag = strrep(cleartag,'Clear','Load');
        hsb = findobj(hf,'Tag',savetag);
        handles = ClearHandles(hsb);
        set(hsb,'UserData',handles);
        % Now clear the actual data
        if strcmp(cleartag,'ClearVel1'), hd = findobj(hf,'Tag','VelName1'); set(hd,'UserData',[]);
        elseif strcmp(cleartag,'ClearVel2'), hd = findobj(hf,'Tag','VelName2'); set(hd,'UserData',[]);
        elseif strcmp(cleartag,'ClearENs'), hd = findobj(hf,'Tag','ENsName'); set(hd,'UserData',[]);
        end
        
    case 'Save'
        % Get the name of the file.  If empty tell user
        SaveFile = get(findobj(hf,'Tag','VoutFile'),'String');
        if isempty(SaveFile), errordlg('No File name given');
        else
            [fid,message] = fopen(SaveFile,'w');
            if fid == -1
                mess = ['Error opening ',SaveFile,' : ',message] ;
                errordlg(mess);
                return
            end
            WriteSave(fid,hf);
        end
        
    case 'HVector'
        % Set up the UIControl for the vector interactions
        VecGUISet(hf, cbname, num,fld); 
        
    case 'GetScale'
        % Extract the scale from the current plot and write into long/lat
        % limits box.  Get the scale from ha
        xlim = get(ha,'XLim'); ylim = get(ha,'YLim');
        % Get handle for long/lat box
        hl = findobj(hf,'tag','LLLimit');
        llstr = sprintf('%6.2f %6.2f %6.2f %6.2f',xlim,ylim);
        set(hl,'String',llstr);
        
    case 'ClearScale'
        % Clears the values in the scale box
        hl = findobj(hf,'tag','LLLimit');
        set(hl,'String',[]);
        
    case 'Redraw'
        % Routine to redraw figure with changes in some options
        % Clear the current plot
        hcb = findobj(hf,'Tag','LoadVel1');
        ClearHandles(hcb);        
        % Get information on Velocity field 1
        hn = findobj(hf,'Tag','VelName1');
        save1 = get(hn,'UserData');
        vel1 = save1.Vel; name1 = save1.Name; % Get the data
        vel1inf = getVelinf(hf, 'VelName1');  % Get the new information from the load area
        % See if we need to apply offsets
        [offs, aligns] = GetOffset(hf);
        vel1n = vel1;
        vel1n(3,:) = vel1(3,:) - offs(1); vel1n(4,:) = vel1(4,:) - offs(2);
       
        % Generate the arrow structure for Velocity field 1
        arrowstr = GenArrowStr(1);
        % Get the scales of the current plot and pass those in
        llsize = [get(ha,'Xlim') get(ha,'Ylim')];
        hndlh1 = Hplot(ha,name1,vel1n,llsize,vel1inf,arrowstr);
        % Save the handles so that we can delete or change later
        set(hcb,'UserData',hndlh1);
        save1 = struct('Vel',vel1,'Name',name1,'VellInf',vel1inf);
        set(hn,'UserData',save1);
        
        % Get information on Velocity field 2
        hcb = findobj(hf,'Tag','LoadVel2');
        ClearHandles(hcb);        

        hn = findobj(hf,'Tag','VelName2');
        save2 = get(hn,'UserData');
        if ~isempty(save2)
            vel2 = save2.Vel; name2 = save2.Name; % Get the data
            vel2inf = getVelinf(hf, 'VelName2');  % Get the new information from the load area
            % See if we need to apply offsets
            [offs, aligns] = GetOffset(hf);
            vel2n = vel2;
            vel2n(3,:) = vel2(3,:) - offs(1) - aligns(1); 
            vel2n(4,:) = vel2(4,:) - offs(2) - aligns(2);
            vel2n(10,:) = vel2n(10,:) - aligns(3);
       
            % Generate the arrow structure for Velocity field 2
            arrowstr = GenArrowStr(2);
            % Get the scales of the current plot and pass those in
            llsize = [get(ha,'Xlim') get(ha,'Ylim')];
            hndlh2 = Hplot(ha,name2,vel2n,llsize,vel2inf,arrowstr);
            % Save the handles so that we can delete or change later
            set(hcb,'UserData',hndlh2);
            save2 = struct('Vel',vel2,'Name',name2,'VellInf',vel2inf);
            set(hn,'UserData',save2);
        else vel2 = []; name2 = [];
        end
        
        % Report numbers of sites
        ReportNum(vel1,vel2);
        % Put arrow on plot
        ShowArrow(hf,ha);
        
    case 'Zoomin'
        % Code to zeeom in on velocity map
        % See which button was pressed (regular zoom or vector zoom)
        %hc = [handles.HVec handles.VVec];
        %for i = 1:length(hc), set(hc,'HitTest','off'); end
        zoomtype = get(hcb,'Tag');
        veczoom = strcmp(zoomtype, 'VecZoomIn');
        % Get the current scales
        limo = [get(ha,'XLim') get(ha,'YLim')];
        %
        % Now let user drag a rbbox accross the screen
        waitforbuttonpress;
        p1 = get(ha,'CurrentPoint');    % button down detected
        rbbox;                   % return figure units
        p2 = get(ha,'CurrentPoint');    % button up detected
        limn = [min(p1(1,1),p2(1,1)) max(p1(1,1),p2(1,1)) ...
                min(p1(1,2),p2(1,2)) max(p1(1,2),p2(1,2))];
        
        VelRedraw(ha, limo, limn, veczoom);
        % Add the current axes to the Zoom Out button so that we can step
        % back through the zooms
        if veczoom 
            hzo = findobj(hf,'tag','VecZoomOut');
        else
            hzo = findobj(hf,'tag','ZoomOut');
        end
        oldll = get(hzo,'UserData');
        llstack = [oldll; limo];
        set(hzo,'UserData',llstack);
        % Set color of button green to show entries in stack
        set(hzo,'BackgroundColor',[0 1 0]);
        %hc = [handles.HVec handles.VVec];
        %for i = 1:length(hc), set(hc,'HitTest','on'); end
        hn = findobj(hf,'Tag','VelName1');
        save1 = get(hn,'UserData');
        vel1 = save1.Vel; name1 = save1.Name; vel1inf = save1.VellInf;
        hn = findobj(hf,'Tag','VelName2');
        save2 = get(hn,'UserData');
        if ~isempty(save2)
            vel2 = save2.Vel; name2 = save2.Name; vel1inf = save2.VellInf;
        else
            vel2 = []; 
        end

        ReportNum(vel1,vel2);
        % Put arrow on plot
        ShowArrow(hf,ha);
        
    case 'Zoomout'
        % See type of zoom out
        zoomtype = get(hcb,'Tag');
        veczoom = strcmp(zoomtype, 'VecZoomOut');
        % Get the current axis sizes
        limo = [get(ha,'XLim') get(ha,'YLim')];
        % get the previous sizes from the button save data
        llstack = get(hcb,'UserData');
        if ~isempty(llstack)
            limn = llstack(length(llstack(:,1)),:);
            VelRedraw(ha,limo,limn,veczoom);
            % Remove the top entry from the stack and save back
            clear lln
            if length(llstack(:,1)) > 1
                lln = llstack(1:length(llstack(:,1))-1,:);
            else
                lln = [];
            end
            set(hcb,'UserData',lln);
            if isempty(lln)
                % change color back to grey
                set(hcb,'BackgroundColor',[0.701961 0.701961 0.701961]);
            end
        end
        hn = findobj(hf,'Tag','VelName1');
        save1 = get(hn,'UserData');
        vel1 = save1.Vel; name1 = save1.Name; vel1inf = save1.VellInf;

        hn = findobj(hf,'Tag','VelName2');
        save2 = get(hn,'UserData');
        if ~isempty(save2)
            vel2 = save2.Vel; name2 = save2.Name; vel1inf = save2.VellInf;
        else
            vel2 = []; 
        end

        ReportNum(vel1,vel2); 
        % Put arrow on plot
        ShowArrow(hf,ha);
        
    case 'ClearZoom'
        % Clears the current zoom stacks, leaving the plots untouched.
        % Find the handles for the two zoom stacks
        hrz = findobj(hf,'Tag','ZoomOut');
        hvz = findobj(hf,'Tag','VecZoomOut');
        set(hrz,'UserData',[],'BackgroundColor',[0.701961 0.701961 0.701961]);
        set(hvz,'UserData',[],'BackgroundColor',[0.701961 0.701961 0.701961]);
        
        
        
    case 'Offset'
        % Either apply the values in the Offvalue box or select area to
        % compute the mean value and offset
        % find the the Offvalue handle and see if strning set
        hov = findobj(hf,'Tag','Offvalue');
        offstr = get(hov,'String');
        % Get the data that we need to work with.  Need a little more
        % thought here.  Currently get Vel1 field
        hn = findobj(hf,'Tag','VelName1');
        save1 = get(hn,'UserData');
        vel1 = save1.Vel; name1 = save1.Name; vel1inf = save1.VellInf;
        hn = findobj(hf,'Tag','VelName2');
        save2 = get(hn,'UserData');
        if ~isempty(save2)
            vel2 = save2.Vel; name2 = save2.Name; vel2inf = save2.VellInf;
        else vel2 = []; name2=[];vel2inf=[];
        end

       
        if isempty(offstr)
            % No values are in the offset bax, User should click and drag
            % an area
            waitforbuttonpress;
            p1 = get(ha,'CurrentPoint');    % button down detected
            rbbox;                   % return figure units
            p2 = get(ha,'CurrentPoint');    % button up detected
            ob = [min(p1(1,1),p2(1,1)) max(p1(1,1),p2(1,1)) ...
                min(p1(1,2),p2(1,2)) max(p1(1,2),p2(1,2))];
            % Make the polynomial
            xpoly = [ob(1);ob(2);ob(2);ob(1);ob(1)];
            ypoly = [ob(3);ob(3);ob(4);ob(4);ob(3)];
            % Now compute the mean velocities in this box
            in = inpolygon(vel1(1,:)',vel1(2,:)',xpoly,ypoly);
            velinp = vel1(:,in); nameinp = name1(in,:);
            stats = WMean(velinp,nameinp);
            offs = [stats(6) stats(2)];
            %offs = [mean(velinp(3,:)) mean(velinp(4,:))];
            % Write the values into the offset box
            offstr = sprintf('%6.2f %6.2f',offs);
            set(hov,'String',offstr);
        end
        [offs, aligns] = GetOffset(hf);
        % Get which field from the tag on the callback object
        hcb1 = findobj(hf,'Tag','LoadVel1');
        ClearHandles(hcb1);
        hcb2 = findobj(hf,'Tag','LoadVel2');
        ClearHandles(hcb2);
        
        % Now apply the offsets to the velocity field 1
        vel1(3,:) = vel1(3,:) - offs(1); vel1(4,:) = vel1(4,:) - offs(2);
        arrowstr = GenArrowStr(1);
        % Get the scales of the current plot and pass those in
        llsize = [get(ha,'Xlim') get(ha,'Ylim')];
        hndlh1 = Hplot(ha,name1,vel1,llsize,vel1inf,arrowstr);
        % Save the handles so that we can delete or change later
        set(hcb1,'UserData',hndlh1);
        
        % Apply the offsets to Velocity field 2
        if ~isempty(vel2)
            vel2(3,:) = vel2(3,:) - offs(1) - aligns(1); 
            vel2(4,:) = vel2(4,:) - offs(2) - aligns(2);
            vel2(10,:) = vel2(10,:) - aligns(3);
            arrowstr = GenArrowStr(2);
            % Get the scales of the current plot and pass those in
            hndlh2 = Hplot(ha,name2,vel2,llsize,vel2inf,arrowstr);
            % Save the handles so that we can delete or change later
            set(hcb2,'UserData',hndlh2);
        end
        
    case 'Align'
        % Either apply the values in the Alignvalue box or select area to
        % compute the mean offset between the fields
        % find the the Offvalue handle and see if strning set
        hov = findobj(hf,'Tag','Alignvalue');
        alignstr = get(hov,'String');
        % Get the data that we need to work with.  Need a little more
        % thought here.  Currently get Vel1 field
        hn = findobj(hf,'Tag','VelName1');
        save1 = get(hn,'UserData');
        vel1 = save1.Vel; name1 = save1.Name; vel1inf = save1.VellInf;
        hn = findobj(hf,'Tag','VelName2');
        save2 = get(hn,'UserData');
        if ~isempty(save2)
            vel2 = save2.Vel; name2 = save2.Name; vel2inf = save2.VellInf;
        else fprintf('No secondary field to align to\n'); return;
        end

       
        if isempty(alignstr)
            % No values are in the align bax, User should click and drag
            % an area
            waitforbuttonpress;
            p1 = get(ha,'CurrentPoint');    % button down detected
            rbbox;                   % return figure units
            p2 = get(ha,'CurrentPoint');    % button up detected
            ob = [min(p1(1,1),p2(1,1)) max(p1(1,1),p2(1,1)) ...
                min(p1(1,2),p2(1,2)) max(p1(1,2),p2(1,2))];
            % Make the polynomial
            xpoly = [ob(1);ob(2);ob(2);ob(1);ob(1)];
            ypoly = [ob(3);ob(3);ob(4);ob(4);ob(3)];
            % Now get the velocity values that are in the box
            in = inpolygon(vel1(1,:)',vel1(2,:)',xpoly,ypoly);
            vel1in = vel1(:,in); name1in = name1(in,:);
            in = inpolygon(vel2(1,:)',vel2(2,:)',xpoly,ypoly);
            vel2in = vel2(:,in); name2in = name2(in,:);
            % Compute the value of the align between the fields
            stats = WAlign(vel1in,name1in,vel2in,name2in);
            aligns = [stats(6) stats(2) stats(10)];
            %offs = [mean(velinp(3,:)) mean(velinp(4,:))];
            % Write the values into the offset box
            alignstr = sprintf('%6.2f %6.2f %6.2f',aligns);
            set(hov,'String',alignstr);
        end
        % Now get the offset and alignment so we can replot
        [offs, aligns] = GetOffset(hf);
        % Get which field from the tag on the callback object
        hcb2 = findobj(hf,'Tag','LoadVel2');
        ClearHandles(hcb2);
        
        % Now apply the offsets to the velocity field 1
        vel2(3,:) = vel2(3,:) - offs(1) - aligns(1); 
        vel2(4,:) = vel2(4,:) - offs(2) - aligns(2); 
        vel2(10,:) = vel2(10,:) - aligns(3);
        arrowstr = GenArrowStr(2);
        % Get the scales of the current plot and pass those in
        llsize = [get(ha,'Xlim') get(ha,'Ylim')];
        % Get the scales of the current plot and pass those in
        hndlh2 = Hplot(ha,name2,vel2,llsize,vel2inf,arrowstr);
        % Save the handles so that we can delete or change later
        set(hcb2,'UserData',hndlh2);
        
    case 'Pan'
        % Find out which button was pressed
        direct = get(hcb,'Tag');
        % Get the scales of the current plot
        llo = [get(ha,'Xlim') get(ha,'Ylim')];
        off = [(llo(2)-llo(1))/2 (llo(4)-llo(3))/2]; 
        if strcmp(direct,'PanU'), lln = [llo(1) llo(2) llo(3)+off(2) llo(4)+off(2)];
        elseif strcmp(direct,'PanD'), lln = [llo(1) llo(2) llo(3)-off(2) llo(4)-off(2)];
        elseif strcmp(direct,'PanL'), lln = [llo(1)-off(1) llo(2)-off(1) llo(3) llo(4)];
        elseif strcmp(direct,'PanR'), lln = [llo(1)+off(1) llo(2)+off(1) llo(3) llo(4)];
        elseif strcmp(direct,'PanO'), lln = [llo(1)-off(1)/2 llo(2)+off(1)/2 llo(3)-off(2)/2 llo(4)+off(2)/2];
        end
            
        % Reset the axes
        if strcmp(direct,'PanO'),  VelRedraw(ha, llo, lln, 1);
        else set(ha,'Xlim',lln(1:2)); set(ha,'Ylim',lln(3:4));
        end
        hn = findobj(hf,'Tag','VelName1');
        save1 = get(hn,'UserData');
        vel1 = save1.Vel; name1 = save1.Name; vel1inf = save1.VellInf;
        %arrowstr = GenArrowStr(1);
        % Get the scales of the current plot and pass those in
        %llsize = [get(ha,'Xlim') get(ha,'Ylim')];
        %hndlh1 = Hplot(ha,name1,vel1,llsize,vel1inf,arrowstr);
        
        hn = findobj(hf,'Tag','VelName2');
        save2 = get(hn,'UserData');
        if ~isempty(save2)
            vel2 = save2.Vel; name2 = save2.Name; vel1inf = save2.VellInf;
            %arrowstr = GenArrowStr(2);
            % Get the scales of the current plot and pass those in
            %hndlh2 = Hplot(ha,name2,vel2,llsize,vel2inf,arrowstr);
        else vel2 = [];
        end

        ReportNum(vel1,vel2);
        % Put arrow on plot
        ShowArrow(hf,ha);
        
    case 'ClearOff'
        % Clears the values written in the offset box
        % Get the handle of the offset box
        ho = findobj(hf,'Tag','Offvalue');
        set(ho,'String',[]);
        
    case 'ClearAlign'
        % Clears the values written in the offset box
        % Get the handle of the offset box
        ho = findobj(hf,'Tag','Alignvalue');
        set(ho,'String',[]);
        
    case 'Profile'
        
        % First select the profile graphically
        [profll,hl,hb] = SelectProfile;
        % Now we need to store the data back in the VelName1 handle
        hn = findobj(hf,'Tag','VelName1');
        %save1 = struct('Vel',vel1,'Name',name1,'VellInf',vel1inf);
        save1 = get(hn,'UserData');
        
        % See which points are in the box
        in = inpolygon(save1.Vel(1,:),save1.Vel(2,:), profll(3:7,1),profll(3:7,2));
        profvel = save1.Vel(:,in); profname=save1.Name(in,:);
        fprintf(1,'There are %d points in profile\n',length(profvel(1,:)));
        hs = plot(profvel(1,:),profvel(2,:),'ko','MarkerFaceColor',[1 0.8 0]);
        %
        % Compute the profile
        [profxy,profvel,profname,profaz] = CompProf(profll,profvel, profname);
        %
        % Now plot the results
        ProfGUI(profxy, profname,profll, profaz);
        
        % Make structure with handles to line, box and symbols.  Save in
        % the pop button user data
        profstr = {hl,hb,hs};
        hp = findobj(hf,'Tag','ProfPop');
        % Get any current handles already saved
        profsave = get(hp,'UserData');
        profsave = [profsave;profstr];
        set(hp,'UserData',profsave);
        set(hp,'BackgroundColor',[0 1 0]);
        
    case 'ProfPop'
        % Find out which button was pressed
        but = get(gcbo,'Tag');
        % Find the saved data
        hp = findobj(hf,'Tag','ProfPop');
        % Get the list of propfiles already saved
        profsave = get(hp,'UserData');
        if isempty(profsave), numsave = 0;
        else numsave = length(profsave(:,1)); end
        % See which set is to be deleted
        if numsave > 0
            if strcmp(but,'ProfPop') % The pop so delete the last one
                try delete(profsave{numsave,:}); end
                if numsave > 1, profsave = profsave(1:numsave-1,:);
                else profsave = [];
                end
            else  % PIP function, so delete initial profile
                try, delete(profsave{1,:}); end
                if numsave > 1, profsave = profsave([2:numsave],:);
                else profsave = [];
                end
            end
            set(hp,'UserData',profsave);
        end
        if isempty(profsave)
            set(hp,'UserData',[],'BackgroundColor',[0.70 0.70 0.70]);
        end
        
    case 'ProfAz'
        % Get the Azimuth of the profile by graphical selection.  Result is
        % written into the ProfAzIn box where it is read by CompProf
        SelectProfAz;
        
    case 'RmDups'
        % Remove sites that have the same velocity and that are with
        % sepified distance
        % Get the separation value
        hs = findobj(hf,'Tag','CloseSep');
        closesep = str2double(get(hs,'String'));
        % Get Data
        hn = findobj(hf,'Tag','VelName1');
        save1 = get(hn,'UserData');
        vel1 = save1.Vel; name1 = save1.Name; vel1inf = save1.VellInf;

        %
        % Now remove duplicates from Velocity Field 1
        save1 = RemoveDups(save1,closesep);
        vel1 = save1.Vel; name1 = save1.Name;
        % Now replot so that plot is consistent with data set
        % If handles already exist for this plot, delete all the graphics
        % objects first
        hcb = findobj(hf,'Tag','LoadVel1');
        ClearHandles(hcb);
        
        % Set the arrow characters based on Primary and parameters
        arrowstr = GenArrowStr(1);
        llsize = [get(ha,'Xlim') get(ha,'Ylim')];
        % Get any offset that we are applying and plot offset values
        [offs, aligns] = GetOffset(hf);
        vel1n = vel1;
        vel1n(3,:) = vel1(3,:) - offs(1); vel1n(4,:) = vel1(4,:) - offs(2);
        hndlh1 = Hplot(ha,name1,vel1n,llsize,vel1inf,arrowstr);
        % Save the handles so that we can delete or change later
        set(hcb,'UserData',hndlh1);
        % Save data set back to the user data of the file name
        set(hn,'UserData',save1);
        %
        % Now remove duplicates from Velocity Field 2
        hn = findobj(hf,'Tag','VelName2');
        save2 = get(hn,'UserData');
        if ~isempty(save2)
            vel2 = save2.Vel; name2 = save2.Name; vel2inf = save2.VellInf;
            save2 = RemoveDups(save2,closesep);
            vel2 = save2.Vel; name2 = save2.Name;
            % Now replot so that plot is consistent with data set
            % If handles already exist for this plot, delete all the graphics
            % objects first
            hcb = findobj(hf,'Tag','LoadVel2');
            ClearHandles(hcb);
        
            % Set the arrow characters based on Primary and parameters
            arrowstr = GenArrowStr(2);
            llsize = [get(ha,'Xlim') get(ha,'Ylim')];
            vel2n = vel2;
            vel2n(3,:) = vel2(3,:) - offs(1) - aligns(1); 
            vel2n(4,:) = vel2(4,:) - offs(2) - aligns(2);
            vel2n(10,:) = vel2n(10,:) - aligns(3);
            hndlh2 = Hplot(ha,name2,vel2n,llsize,vel2inf,arrowstr);
            % Save the handles so that we can delete or change later
            set(hcb,'UserData',hndlh2);
            % Save data set back to the user data of the file name
            set(hn,'UserData',save2);
        else vel2 = []; name2=[]; vel2inf = [];
        end
            
        % Finally report the number of stations shown on plot
        ReportNum(vel1,vel2);
        % Put arrow on plot
        ShowArrow(hf,ha);
        
    case 'CloseStats'
        % Report the statistics of nearby sites
        % Get the separation value
        hs = findobj(hf,'Tag','CloseSep');
        closesep = str2double(get(hs,'String'));
        % Get Data
        hn = findobj(hf,'Tag','VelName1');
        save1 = get(hn,'UserData');
        vel1 = save1.Vel; name1 = save1.Name; vel1inf = save1.VellInf;
        %
        % Report on the statistics of nearby sites
        CloseStats(save1,closesep);
        
        hn = findobj(hf,'Tag','VelName2');
        save2 = get(hn,'UserData');
        if ~isempty(save2)
            vel2 = save2.Vel; name2 = save2.Name; vel2inf = save2.VellInf;
            %
            % Report on the statistics of nearby sites
            CloseStats(save2,closesep);
        else vel2 = [];
        end
        % Finally report the number of stations shown on plot
        ReportNum(vel1,vel2);
        
    case 'Feature'
        % Load the feature file.  Get information about the feature file.
        % Get which button pressed
        Fopt = get(gcbo,'Tag');
        he = findobj(hf,'Tag','FeatureEntry');
        hdfs = get(he,'UserData');
        fname = get(he,'String'); % set(he,'String',[]);
        new = 1; done = 0;
        if isempty(fname) 
            hs = findobj(hf,'Tag','FeatFiles');
            list = get(hs,'String'); sel = get(hs,'Value');
            if ~isempty(sel) && sel > 0
                fname = list(sel,:);
                fname = strrep(fname,' ','');
                new = 0;
            else
                fprintf('No file name in feature enty\n');
                done = 1;
            end
        end
        if strcmp(Fopt,'ClearNm')
           set(he,'String',[]);   
           done = 1;
        end
        if ~done 
            CF = loadfeat(fname);
            if ~new  
               % If this is an old feature being replotted, remove the
               % original
               try if hdfs(sel) ~= 999; delete(hdfs(sel)); end ; end
            end
            if ~isempty(CF) 
                if strcmp(Fopt,'LoadFBk')
                    hdf = plot(CF(:,1),CF(:,2),'k');
                elseif strcmp(Fopt,'LoadFGr')
                    hdf = plot(CF(:,1),CF(:,2),'g');
                elseif strcmp(Fopt,'LoadFYe') 
                    hdf = plot(CF(:,1),CF(:,2),'y');
                elseif strcmp(Fopt,'DotsFBr') 
                    hdf = plot(CF(:,1),CF(:,2),'*','Color',[1.0 0.5 0.0],'MarkerSize',2);
                elseif strcmp(Fopt,'ClearFt')
                    hdf = 999;
                end
                if new 
                    hs = findobj(hf,'Tag','FeatFiles');
                    list = get(hs,'String'); 
                    list = strvcat(list,fname);
                    set(hs,'String',list,'Value',1);
                    hdfs = [ hdfs hdf];
                else
                    % Replace then entry that was deleted
                    hdfs(sel) = hdf;
                end
                set(he,'UserData',hdfs);
            end
        end
      
        
    case 'IDPoints'
        % Identify all points in the region selected by by the user.  This
        % is to handle the case of similar points that can not be clicked
        % on
        % Get the region selected by the user
        waitforbuttonpress;
        p1 = get(ha,'CurrentPoint');    % button down detected
        rbbox;                   % return figure units
        p2 = get(ha,'CurrentPoint');    % button up detected
        ob = [min(p1(1,1),p2(1,1)) max(p1(1,1),p2(1,1)) ...
              min(p1(1,2),p2(1,2)) max(p1(1,2),p2(1,2))];
        % Make the polynomial
        xpoly = [ob(1);ob(2);ob(2);ob(1);ob(1)];
        ypoly = [ob(3);ob(3);ob(4);ob(4);ob(3)];
        
        % Get Data for velocity field one
        hn = findobj(hf,'Tag','VelName1');
        save1 = get(hn,'UserData');
        vel1 = save1.Vel; name1 = save1.Name; vel1inf = save1.VellInf;
        % See which points are in the polynomial
        in = inpolygon(vel1(1,:)',vel1(2,:)',xpoly,ypoly);
        if sum(in) > 0 
            vel1in = vel1(:,in); name1in = name1(in,:);
            num = length(vel1in(1,:)); totl = num+1;
            vtext = sprintf('ID Points: VELOCITY FIELD 1: There %d points in region selected',num);
            for i = 1:num
              vline = sprintf('%s LL %8.4f %8.4f deg Ve %6.2f +- %6.2f; Vn %6.2f +- %6.2f; Vu %6.2f +- %6.2f mm/yr', ...
                 name1in(i,:), vel1in([1 2 3 7 4 8 10 12],i));
                vtext = strvcat(vtext, vline);
            end
        else
           vtext = sprintf('ID Points: VELOCITY FIELD 1: There no points in region selected');
           totl = 1;
        end
        %
        hn = findobj(hf,'Tag','VelName2');
        save2 = get(hn,'UserData');
        if ~isempty(save2)
            vel2 = save2.Vel; name2 = save2.Name; vel2inf = save2.VellInf;
            in = inpolygon(vel2(1,:)',vel2(2,:)',xpoly,ypoly);
            if sum(in) > 0
                vel2in = vel2(:,in); name2in = name2(in,:);
                num = length(vel2in(1,:));
                vline = sprintf('ID Points: VELOCITY FIELD 2: There %d points in region selected',num);
                vtext = strvcat(vtext, vline);
                for i = 1:num
                    vline = sprintf('%s LL %8.4f %8.4f deg Ve %6.2f +- %6.2f; Vn %6.2f +- %6.2f; Vu %6.2f +- %6.2f mm/yr', ...
                        name2in(i,:), vel2in([1 2 3 7 4 8 10 12],i));
                    vtext = strvcat(vtext, vline);
                end
                totl = totl+num+1;
            end
        end
        disp(vtext);
        % Get size of current axes
        szfg = get(gcf,'Position');
        pos = [szfg(3)-625 szfg(4)-totl*13 625 totl*13];
              
        uicontrol('Parent',gcf, ...
	           'Units','pixels', ...
	          'Position',pos, ...
              'BackgroundColor',[1 1 0.78], ...
	          'String',vtext, ...
              'FontSize',9, ...
              'FontName','Courier', ...
              'HorizontalAlignment','left', ...
              'ButtonDownFcn','delete(gcbo)', ...
	          'Style','text', 'Enable','inactive', ...
	          'Tag','OutResult2');
          drawnow;
        
      case 'SWAP'
          % Code to swap the primary and secondary velocity fields
          % To do this need to switch the names in the field names;
          % swap the actual fields and then redraw.
          vel1inf = getVelinf(hf, 'VelName1');
          if isempty(vel1inf.FileName), errordlg('No Primary Velocity Field');
          else
              % See if there is a secondary velocity field
              vel2inf = getVelinf(hf, 'VelName2');
              if isempty(vel2inf.FileName)
                  errordlg('No Secondary Velocity Field');
              else
                  % All OK, do the swap
                  hcb = findobj(hf,'Tag','LoadVel1');
                  ClearHandles(hcb);        
                  % Get information on Velocity field 1
                  hn = findobj(hf,'Tag','VelName1');
                  save1 = get(hn,'UserData');
                  
                  % Get information in secondary field
                  hcc = findobj(hf,'Tag','LoadVel2');
                  ClearHandles(hcc);        
                  % Get information on Velocity field 1
                  hm = findobj(hf,'Tag','VelName2');
                  save2 = get(hm,'UserData');
                  
                  % OK Swap the user data and names and replot
                  savet = save1; save1 = save2; save2 = savet; clear savet;
                  veltinf = vel1inf; vel1inf = vel2inf; vel2inf = veltinf; clear veltinf;
                  
                  % replot
                  llsize = [get(ha,'Xlim') get(ha,'Ylim')];  % Get current size
                  arrowstr = GenArrowStr(1);
                  vel1 = save1.Vel; name1 = save1.Name; % Get the data
                  hndlh1 = Hplot(ha,name1,vel1,llsize,vel1inf,arrowstr);
                  set(hcb,'UserData',hndlh1); set(hn,'String',vel1inf.FileName);
                  set(hn,'UserData',save1);
                  arrowstr = GenArrowStr(2);
                  vel2 = save2.Vel; name2 = save2.Name; % Get the data
                  hndlh2 = Hplot(ha,name2,vel2,llsize,vel2inf,arrowstr);
                  set(hcc,'UserData',hndlh2); set(hm,'String',vel2inf.FileName);
                  set(hm,'UserData',save2);
                  % Finally report the number of stations shown on plot
                  ReportNum(vel1,vel2);                  
              end
          end
          
    case 'Print'
       % Print figure.  Read the options from the PrintOpt box
       ho = findobj(gcf,'Tag','PrintOpts');
       propts = get(ho,'String');
       % Find the blanks in the string and break into separate sections
       kb = findstr(propts,' '); kb = [kb length(propts)+1];
       lkb = length(kb);
       str2=[]; str3=[];str4=[];str5=[];
       if lkb > 0, str1 = propts(1:kb(1)-1); end
       if lkb > 1, str2 = propts(kb(1)+1:kb(2)-1); end
       if lkb > 2, str3 = propts(kb(2)+1:kb(3)-1); end
       if lkb > 3, str4 = propts(kb(3)+1:kb(4)-1); end
       if lkb > 4, str5 = propts(kb(4)+1:kb(5)-1); end
       print(gcf,str1,str2,str3,str4,str5);
       
    case 'PageSetup'
       % Page setup 
       pagesetupdlg(hf)

        
end   % End of switch options
