function fig = velview
% VELVIEW: Main setup of GUI for displaying velocity plots
if nargin == 0
   clear all
%
%  Print a small help description
   velver = 2.01;
   fprintf(1,'+++++++++++++++++++++++++++\n');
   fprintf(1,'+ VELVIEW    Version %4.2f +\n',velver);
   fprintf(1,'+++++++++++++++++++++++++++\n');
   fprintf(1,'Program to plot velocity fields and display time series of GPS positions\n');
   fprintf(1,'Velocity fields and timeseries can be in original globk formats or PBO velocity and Position\n\n');
   fprintf(1,'Version 2.00: PBO .vel and .pos formats introdued\n');
   fprintf(1,'Version 2.01: Changed vertical velocity plotting\n\n');
end

% Reset the default line width in user has overwritten
set(0,'DefaultLineLineWidth',0.5);
set(0,'DefaultAxesBox','on');
set(0,'DefaultAxesTickDir','in');
set(0,'DefaultUicontrolFontSize',10)
set(0,'DefaultAxesFontSize',10)

% Set root units to pixels and get screen size
set(0,'Units','pixels') ;
scnsize = get(0,'ScreenSize');

% Set an effective Max screen Size
if scnsize(3) > 1280 , scnsize(3) = 1280; end
if scnsize(4) >  960 , scnsize(4) =  960; end
 
% Compute the Figure size we want
figsize = [(scnsize(3)-scnsize(1))*0.80 (scnsize(4)-scnsize(2))*0.80];

% Generate the basic figure and then call the setup routine (which is also
% used for the resize function)

pos = [figsize(1)*0.1 figsize(2)*0.1 figsize(1) figsize(2) ];
h0 = figure('Units','pixels', ...
	'Color',[0.8 0.8 0.8], ...
	'Position',pos, ...
    'MenuBar','figure', ...
    'PaperPositionMode','auto', ...
	'Tag','FigVel');

VelFigSet('Load');    % Resize version is 'Resz'

%velgui('ClearAll');
%if 1 == 2 
%    VecActions(1,1);
%end

% Set this after initial figure call because ResizeFcn is called in figure
% before the initial load
set(h0,'ResizeFcn','VelFigSet(''Resz'')');

% fig = 0 ;
if nargout > 0, fig = h0; end
